@@ -100,6 +100,13 @@ _nc_de_print_H_list (const gchar *option_name, const gchar *value, gpointer data
   return TRUE;
 }
 
+static gboolean
+_nc_de_print_H_BAO_list (const gchar *option_name, const gchar *value, gpointer data, GError **error)
+{
+  ncm_cfg_enum_print_all (NC_TYPE_DATA_HUBBLE_BAO_ID, "Hubble BAO samples");
+  return TRUE;
+}
+
 static gboolean
 _nc_de_print_cluster_list (const gchar *option_name, const gchar *value, gpointer data, GError **error)
 {
@@ -116,16 +123,19 @@ nc_de_opt_get_data_simple_group (NcDEDataSimpleEntries *de_data_simple, GOptionE
     { "bao-list",        0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, &_nc_de_print_bao_list,      "Print all BAO data avaliable.",         NULL },
     { "cmb-list",        0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, &_nc_de_print_cmb_list,      "Print all CMB data avaliable.",         NULL },
     { "H-list",          0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, &_nc_de_print_H_list,        "Print all Hubble data avaliable.",      NULL },
+    { "H-BAO-list",      0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, &_nc_de_print_H_BAO_list,    "Print all Hubble BAO data avaliable.",  NULL },
     { "cluster-list",    0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, &_nc_de_print_cluster_list,  "Print all Cluster data avaliable.",     NULL },
-    { "snia-id",    'S', 0, G_OPTION_ARG_STRING, &de_data_simple->snia_id,      "ID of the SNe Ia sample to use",                                NULL },
+    { "snia-id",    'S', 0, G_OPTION_ARG_STRING,       &de_data_simple->snia_id,      "ID of the SNe Ia sample to use",                                NULL },
     { "snia-prop",       0,                    0, G_OPTION_ARG_STRING,   &de_data_simple->snia_prop,  "The SNe Ia analysis object properties", NULL },
-    { "snia-use-det", 0, 0, G_OPTION_ARG_NONE,   &de_data_simple->snia_use_det, "Whenever to use the normalized Likelihood when fitting SN Ia data", NULL },
-    { "bao-id",     'B', 0, G_OPTION_ARG_STRING, &de_data_simple->bao_id,       "ID of the BAO sample to use",                                   NULL },
-    { "cmb-id",     'C', 0, G_OPTION_ARG_STRING, &de_data_simple->cmb_id,       "ID of the CMB sample to use",                                   NULL },
-    { "H-id",       'E', 0, G_OPTION_ARG_STRING, &de_data_simple->H_id,         "Use the H(z_i) data sample",                                    NULL },
-    { "cluster-id", 'U', 0, G_OPTION_ARG_STRING, &de_data_simple->cluster_id,   "Use cluster abundance data",                                    NULL },
-    { "H0_Hst",     'H', 0, G_OPTION_ARG_NONE,   &de_data_simple->H0_Hst,       "Use the HST H0 data (single gaussian (H0 - 73.8) / 2.4)",       NULL },
-    { "BBN",        'N', 0, G_OPTION_ARG_NONE,   &de_data_simple->BBN,          "Use BBN Prior",                                                 NULL },
+    { "snia-use-det", 0, 0, G_OPTION_ARG_NONE,         &de_data_simple->snia_use_det, "Whenever to use the normalized Likelihood when fitting SN Ia data", NULL },
+    { "bao-id",     'B', 0, G_OPTION_ARG_STRING_ARRAY, &de_data_simple->bao_id,       "ID of the BAO sample to use",                                   NULL },
+    { "cmb-id",     'C', 0, G_OPTION_ARG_STRING,       &de_data_simple->cmb_id,       "ID of the CMB sample to use",                                   NULL },
+    { "H-id",       'E', 0, G_OPTION_ARG_STRING_ARRAY, &de_data_simple->H_id,         "Use the H(z) data sample",                                    NULL },
+    { "H-BAO-id",   'F', 0, G_OPTION_ARG_STRING_ARRAY, &de_data_simple->H_BAO_id,     "Use the H(z)r_s/(1 + z) data sample",                                    NULL },
+    { "cluster-id", 'U', 0, G_OPTION_ARG_STRING,       &de_data_simple->cluster_id,   "Use cluster abundance data",                                    NULL },
+    { "H0_Hst",     'H', 0, G_OPTION_ARG_NONE,         &de_data_simple->H0_Hst,       "Use the HST H0 data (single gaussian (H0 - 73.8) / 2.4)",       NULL },
+    { "BBN",        'N', 0, G_OPTION_ARG_NONE,         &de_data_simple->BBN,          "Use BBN Prior",                                                 NULL },
+    { "BBN-Omega_b",  0, 0, G_OPTION_ARG_NONE,         &de_data_simple->BBN_Ob,       "Use BBN Omega_b * h2 Prior = 0.022 +/- 0.002",                  NULL },
     { NULL }
   };
   GOptionGroup *data_simple_group = g_option_group_new ("data", " - Cosmological data options", "Show help options related to the dataset to be used.", NULL, NULL);
@@ -143,9 +153,9 @@ nc_de_opt_get_data_cluster_group (NcDEDataClusterEntries *de_data_cluster, GOpti
 {
   GOptionEntry entries_cluster[] =
   {
-    { "window",        0, 0, G_OPTION_ARG_STRING,         &de_data_cluster->window_name,           "Which window to use, NcWindowTophat: Top Hat (default), NcWindowGaussian: Gaussian", NULL },
-    { "transfer",      0, 0, G_OPTION_ARG_STRING,         &de_data_cluster->transfer_name,         "Which transfer function to use, NcTransferFuncBBKS: BBKS, NcTransferFuncEH: EH (default)", NULL },
-    { "multiplicity",  0, 0, G_OPTION_ARG_STRING,         &de_data_cluster->multiplicity_name,     "Which multiplicity function to use, NcMultiplicityFuncPS: Press-Schechter, NcMultiplicityFuncST: Sheth-Tormen, NcMultiplicityFuncJenkins: Jenkins et al., NcMultiplicityFuncWarren: Warren et al., NcMultiplicityFuncTinker: Tinker (default), NcMultiplicityFuncTinkerMean: Tinker et al. (mean), NcMultiplicityFuncTinkerCrit: Tinker et al. (critical)", NULL },
+    { "window",        0, 0, G_OPTION_ARG_STRING,         &de_data_cluster->window_name,           "Which window to use", NULL },
+    { "transfer",      0, 0, G_OPTION_ARG_STRING,         &de_data_cluster->transfer_name,         "Which transfer function to use", NULL },
+    { "multiplicity",  0, 0, G_OPTION_ARG_STRING,         &de_data_cluster->multiplicity_name,     "Which multiplicity function to use", NULL },
     { "cluster-m",     0, 0, G_OPTION_ARG_STRING,         &de_data_cluster->clusterm_ser,          "Which NcClusterMass object to use", NULL },
     { "cluster-z",     0, 0, G_OPTION_ARG_STRING,         &de_data_cluster->clusterz_ser,          "Which NcClusterRedshift object to use", NULL },
     { "mf_ds_index",   0, 0, G_OPTION_ARG_INT,            &de_data_cluster->mf_ds_index,           "Determines the coefficients of the multiplicity function.", NULL },
@@ -190,27 +200,33 @@ nc_de_opt_get_fit_group (NcDEFitEntries *de_fit, GOptionEntry **de_fit_entries)
 {
   GOptionEntry fit_entries[] =
   {
-    { "out",            0, 0, G_OPTION_ARG_FILENAME,     &de_fit->file_out,      "Output filename.", "output.dat" },
-    { "fit",            0, 0, G_OPTION_ARG_NONE,         &de_fit->fit,           "Fit model using the selected data.", NULL},
-    { "fit-type",       0, 0, G_OPTION_ARG_STRING,       &de_fit->fit_type,      "Fitting object to be used.", NULL },
-    { "fit-diff",       0, 0, G_OPTION_ARG_STRING,       &de_fit->fit_diff,      "Fitting differentiation algorithim method.", NULL },
-    { "fit-algo",       0, 0, G_OPTION_ARG_STRING,       &de_fit->fit_algo,      "Fitting algorithim.", NULL },
-    { "fit-list",       0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, &_nc_de_print_fit_list,  "Print all the minimization/differentiation objects avaliable.", NULL },
-    { "n-sigma",        0, 0, G_OPTION_ARG_INT,          &de_fit->nsigma,        "Confidence region probability 1, 2 or 3 sigmas. A zero value calculate all three confidence regions.", NULL },
-    { "n-sigma-fisher", 0, 0, G_OPTION_ARG_INT,          &de_fit->nsigma_fisher, "Confidence region (Fisher matrix) probability 1, 2 or 3 sigmas. A zero value calculate all three confidence regions.", NULL },
-    { "cr-x",           0, 0, G_OPTION_ARG_INT,          &de_fit->bidim_cr[0],   "Confidence region x parameter", NULL },
-    { "cr-y",           0, 0, G_OPTION_ARG_INT,          &de_fit->bidim_cr[1],   "Confidence region y parameter", NULL },
-    { "max-iter",       0, 0, G_OPTION_ARG_INT,          &de_fit->max_iter,      "Max number of iterations used by the minimization algorithms", NULL },
-    { "err-param",      0, 0, G_OPTION_ARG_STRING_ARRAY, &de_fit->onedim_cr,     "Calculate the one dimensional confidence region", NULL },
-    { "resample",       0, 0, G_OPTION_ARG_NONE,         &de_fit->resample,      "Resample model using default params", NULL },
-    { "msg-level",      0, 0, G_OPTION_ARG_INT,          &de_fit->msg_level,     "Fit message level (0: no msg, 1: simple, 2: full)", NULL },
-    { "montecarlo",     0, 0, G_OPTION_ARG_INT,          &de_fit->montecarlo,    "Resample the original data 'montecarlo' times.", NULL},
-    { "mc-ni",          0, 0, G_OPTION_ARG_INT,          &de_fit->mc_ni,         "Start the 'montecarlo' at the ni realization.", NULL},
-    { "fiducial",       0, 0, G_OPTION_ARG_NONE,         &de_fit->fiducial,      "Use the fiducial model to resample.", NULL},
-    { "mc-data",        0, 0, G_OPTION_ARG_NONE,         &de_fit->mc_data,       "Print all data from monte carlo.", NULL},
-    { "fisher",         0, 0, G_OPTION_ARG_NONE,         &de_fit->fisher,        "Calculated the Fisher matrix.", NULL},
-    { "save-fisher",    0, 0, G_OPTION_ARG_NONE,         &de_fit->save_fisher,   "Create a file and print the Fisher matrix.", NULL},
-    { "save-best-fit",  0, 0, G_OPTION_ARG_NONE,         &de_fit->save_best_fit, "Create a file and print the cosmological parameters (both best-fit and fixed ones).", NULL},
+    { "out",              0, 0, G_OPTION_ARG_FILENAME,     &de_fit->file_out,         "Output filename.", "output.dat" },
+    { "fit",              0, 0, G_OPTION_ARG_NONE,         &de_fit->fit,              "Fit model using the selected data.", NULL},
+    { "fit-type",         0, 0, G_OPTION_ARG_STRING,       &de_fit->fit_type,         "Fitting object to be used.", NULL },
+    { "fit-diff",         0, 0, G_OPTION_ARG_STRING,       &de_fit->fit_diff,         "Fitting differentiation algorithim method.", NULL },
+    { "fit-algo",         0, 0, G_OPTION_ARG_STRING,       &de_fit->fit_algo,         "Fitting algorithim.", NULL },
+    { "fit-list",         0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, &_nc_de_print_fit_list,  "Print all the minimization/differentiation objects avaliable.", NULL },
+    { "n-sigma",          0, 0, G_OPTION_ARG_INT,          &de_fit->nsigma,           "Confidence region probability 1, 2 or 3 sigmas. A zero value calculate all three confidence regions.", NULL },
+    { "n-sigma-fisher",   0, 0, G_OPTION_ARG_INT,          &de_fit->nsigma_fisher,    "Confidence region (Fisher matrix) probability 1, 2 or 3 sigmas. A zero value calculate all three confidence regions.", NULL },
+    { "cr-x",             0, 0, G_OPTION_ARG_INT,          &de_fit->bidim_cr[0],      "Confidence region x parameter", NULL },
+    { "cr-y",             0, 0, G_OPTION_ARG_INT,          &de_fit->bidim_cr[1],      "Confidence region y parameter", NULL },
+    { "max-iter",         0, 0, G_OPTION_ARG_INT,          &de_fit->max_iter,         "Max number of iterations used by the minimization algorithms", NULL },
+    { "err-param",        0, 0, G_OPTION_ARG_STRING_ARRAY, &de_fit->onedim_cr,        "Calculate the one dimensional confidence region", NULL },
+    { "resample",         0, 0, G_OPTION_ARG_NONE,         &de_fit->resample,         "Resample model using default params", NULL },
+    { "msg-level",        0, 0, G_OPTION_ARG_INT,          &de_fit->msg_level,        "Fit message level (0: no msg, 1: simple, 2: full)", NULL },
+    { "montecarlo",       0, 0, G_OPTION_ARG_INT,          &de_fit->montecarlo,       "Resample the original data 'montecarlo' times.", NULL},
+    { "mc-ni",            0, 0, G_OPTION_ARG_INT,          &de_fit->mc_ni,            "Start the 'montecarlo' at the ni realization.", NULL},
+    { "fiducial",         0, 0, G_OPTION_ARG_STRING,       &de_fit->fiducial,         "Use the fiducial model to resample.", NULL},
+    { "mc-data",          0, 0, G_OPTION_ARG_NONE,         &de_fit->mc_data,          "Print all data from monte carlo.", NULL},
+    { "fisher",           0, 0, G_OPTION_ARG_NONE,         &de_fit->fisher,           "Calculated the Fisher matrix.", NULL},
+    { "kinematics-sigma", 0, 0, G_OPTION_ARG_NONE,         &de_fit->kinematics_sigma, "Compute q(z), E(z)^2 and E(z)^-2 plus 1sigma error bar from the Fisher matrix.", NULL},
+    { "kinematics-z-max", 0, 0, G_OPTION_ARG_DOUBLE,       &de_fit->kinematics_z,     "Max redshift to calculate q(z), E(z)^2 and E(z)^-2.", NULL},
+    { "kinematics-n",     0, 0, G_OPTION_ARG_INT,          &de_fit->kinematics_n,     "Number of points in the redshift interval to calculate q(z), E(z)^2 and E(z)^-2.", NULL},
+    { "qspline-cp",       0, 0, G_OPTION_ARG_NONE,         &de_fit->qspline_cp,       "Include the continuity priors on a NcHICosmoQSpline model.", NULL},
+    { "qspline-cp-sigma", 0, 0, G_OPTION_ARG_DOUBLE,       &de_fit->qspline_cp_sigma, "Value of sigma for the continuity priors.", NULL},
+    { "save-fisher",      0, 0, G_OPTION_ARG_NONE,         &de_fit->save_fisher,      "Create a file and print the Fisher matrix.", NULL},
+    { "save-best-fit",    0, 0, G_OPTION_ARG_NONE,         &de_fit->save_best_fit,    "Create a file and print the cosmological parameters (both best-fit and fixed ones).", NULL},
+    { "save-mset",        0, 0, G_OPTION_ARG_STRING,       &de_fit->save_mset,        "Save NcmMSet to a file for future usage.", NULL},
     { NULL }
   };
   GOptionGroup *fit_group = g_option_group_new ("fit", " - Choices of statistical analysis", "Show help options related to model fitting", NULL, NULL);
