@@ -53,7 +53,7 @@ struct _NcDEModelEntries
   gboolean help_names;
 };
 
-#define NC_DE_MODEL_ENTRIES {"NcHICosmoDEXcdm", FALSE, FALSE, FALSE, FALSE }
+#define NC_DE_MODEL_ENTRIES {"NcHICosmoDEXcdm", FALSE, FALSE, FALSE, FALSE}
 
 typedef struct _NcDEDataSimpleEntries NcDEDataSimpleEntries;
 
@@ -66,16 +66,18 @@ struct _NcDEDataSimpleEntries
 {
   gchar *snia_id;
   gchar *snia_prop;
-  gchar *bao_id;
+  gchar **bao_id;
   gchar *cmb_id;
-  gchar *H_id;
+  gchar **H_id;
+  gchar **H_BAO_id;
   gchar *cluster_id;
   gboolean H0_Hst;
   gboolean BBN;
+  gboolean BBN_Ob;
   gboolean snia_use_det;
 };
 
-#define NC_DE_DATA_SIMPLE_ENTRIES {NULL, NULL, NULL, NULL, NULL, NULL, FALSE, FALSE, FALSE}
+#define NC_DE_DATA_SIMPLE_ENTRIES {NULL, NULL, NULL, NULL, NULL, NULL, NULL, FALSE, FALSE, FALSE, FALSE}
 
 typedef struct _NcDEDataClusterEntries NcDEDataClusterEntries;
 
@@ -129,17 +131,23 @@ struct _NcDEFitEntries
   gint msg_level;
   gint montecarlo;
   gint mc_ni;
-  gboolean fiducial;
+  gchar *fiducial;
   gboolean mc_data;
   gboolean fisher;
+  gboolean kinematics_sigma;
+  gdouble kinematics_z;
+  gint kinematics_n;
+  gboolean qspline_cp;
+  gdouble qspline_cp_sigma;
   gboolean save_fisher;
   gboolean save_best_fit;
+  gchar *save_mset;
 };
 
 #ifdef NUMCOSMO_HAVE_NLOPT
-#define NC_DE_FIT_ENTRIES { NULL, FALSE, "nlopt",   "numdiff-forward", NULL, -1, -1, {-1, -1}, NULL, NCM_FIT_MAXEVAL, FALSE, NCM_FIT_RUN_MSGS_SIMPLE, -1, 0, FALSE, FALSE, FALSE, FALSE}
+#define NC_DE_FIT_ENTRIES { NULL, FALSE, "nlopt",   "numdiff-forward", NULL, -1, -1, {-1, -1}, NULL, NCM_FIT_MAXITER, FALSE, NCM_FIT_RUN_MSGS_SIMPLE, -1, 0, NULL, FALSE, FALSE, FALSE, 1.0, 100, FALSE, 1.0, FALSE, FALSE, NULL}
 #else
-#define NC_DE_FIT_ENTRIES { NULL, FALSE, "gsl-mms", "numdiff-forward", NULL, -1, -1, {-1, -1}, NULL, NCM_FIT_MAXEVAL, FALSE, NCM_FIT_RUN_MSGS_SIMPLE, -1, 0, FALSE, FALSE, FALSE, FALSE}
+#define NC_DE_FIT_ENTRIES { NULL, FALSE, "gsl-mms", "numdiff-forward", NULL, -1, -1, {-1, -1}, NULL, NCM_FIT_MAXITER, FALSE, NCM_FIT_RUN_MSGS_SIMPLE, -1, 0, NULL, FALSE, FALSE, FALSE, 1.0, 100, FALSE, 1.0, FALSE, FALSE, NULL}
 #endif
 
 GOptionGroup *nc_de_opt_get_run_group (NcDERunEntries *de_run);
