@@ -28,23 +28,43 @@
  * @title: Top-hat Window Function
  * @short_description: Provides a #NcWindow of top-hat type filter.
  * 
- * This object implements the #NcWindow abstract class for a top-hat window function.
- * See also <link linkend="sec_wf_th">Top-hat</link> for more details.
- *
+ * This object implements the #NcWindow class for a top-hat window function.
+ * 
+ * This object returns the top hat window function in the real space.
+ * \begin{align}
+ * W_{TH}(r, R) = \frac{3}{4\pi R^3} \left\{ \begin{array} {ll}
+ * 1 & \leq R\\
+ * 0 & &gt; R.
+ * \end{array} \right.
+ * \end{align}
+ * The mass enclosed within the volume selected by this window function is $M_{TH}(R)=
+ * \frac{4\pi}{3}\overline{\rho} R^3$,where $\overline{\rho}(z)$ is the mean density of the
+ * universe at redshift $z$.
+ * 
+ * The top-hat window function in the Fourier space is given by
+ * 
+ * \begin{align}
+ * W_{th}(k, R) &= \frac{3}{(kR)^3}(\sin kR - (kR)\cos kR) \\
+ * &= \frac{3}{(kR)} j_1(kR),
+ * \end{align}
+ * where $j_\nu(kR)$ is the spherical Bessel function.
+ * 
+ * The first derivative with respect to $R$
+ * \begin{equation}
+ * \frac{dW_{TH}(k, R)}{dR} = \frac{-9}{k^3 R^4} (\sin kR - (kR)\cos kR) + \frac{3}{k R^2} \sin kR.
+ * \end{equation}
+ * 
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
 
-#include <stdio.h>
-#include <stdlib.h>
+#include "lss/nc_window_tophat.h"
 #include <math.h>
-#include <gsl/gsl_integration.h>
 #include <gsl/gsl_sf_bessel.h>
 
-
 G_DEFINE_TYPE (NcWindowTophat, nc_window_tophat, NC_TYPE_WINDOW);
 
 /**
