@@ -100,6 +100,10 @@
 #include <fftw3.h>
 #endif /* NUMCOSMO_HAVE_FFTW3 */
 
+#ifndef G_VALUE_INIT
+#define G_VALUE_INIT {0}
+#endif
+
 static gchar *numcosmo_path = NULL;
 static gboolean numcosmo_init = FALSE;
 static FILE *_log_stream = NULL;
@@ -107,6 +111,8 @@ static guint _log_msg_id = 0;
 static gboolean _enable_msg = TRUE;
 static gboolean _enable_msg_flush = TRUE;
 static gsl_error_handler_t *gsl_err = NULL;
+static GHashTable *named_instances_name_ptr = NULL;
+static GHashTable *named_instances_ptr_name = NULL;
 
 static void
 _ncm_cfg_log_message (const gchar *log_domain, GLogLevelFlags log_level, const gchar *message, gpointer user_data)
@@ -139,13 +145,19 @@ ncm_cfg_init (void)
 #if (GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 32)
   g_thread_init (NULL);
 #endif
+
+#if (GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 36)
   g_type_init();
+#endif
 
   g_setenv ("CUBACORES", "0", TRUE);
 
   _log_msg_id = g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE | G_LOG_LEVEL_DEBUG, _ncm_cfg_log_message, NULL);
   _log_stream = stdout;
 
+  ncm_cfg_register_obj (NCM_TYPE_VECTOR);
+  ncm_cfg_register_obj (NCM_TYPE_MATRIX);
+
   ncm_cfg_register_obj (NCM_TYPE_SPLINE);
   ncm_cfg_register_obj (NCM_TYPE_SPLINE_CUBIC);
   ncm_cfg_register_obj (NCM_TYPE_SPLINE_CUBIC_NOTAKNOT);
@@ -228,6 +240,12 @@ ncm_cfg_init (void)
 
   ncm_cfg_register_obj (NC_TYPE_SNIA_DIST_COV);
 
+  named_instances_name_ptr = g_hash_table_new_full (g_str_hash, g_str_equal, 
+                                                    &g_free, &g_object_unref);
+
+  named_instances_ptr_name = g_hash_table_new_full (g_direct_hash, g_direct_equal,
+                                                    &g_object_unref, &g_free);
+  
   numcosmo_init = TRUE;
   return;
 }
@@ -508,6 +526,204 @@ ncm_cfg_rng_set_state (gchar *state)
   g_strfreev (name_state);
 }
 
+/**
+ * ncm_cfg_is_named_instance:
+ * @obj: (type GObject): FIXME
+ * 
+ * FIXME
+ * 
+ * Returns: FIXME
+ */
+gboolean 
+ncm_cfg_is_named_instance (gpointer obj)
+{
+  g_assert (numcosmo_init);
+  g_assert (G_IS_OBJECT (obj));
+  return (g_hash_table_lookup (named_instances_ptr_name, obj) != NULL);
+}
+
+/**
+ * ncm_cfg_exist_named_instance:
+ * @name: FIXME
+ * 
+ * FIXME
+ * 
+ * Returns: FIXME
+ */
+gboolean 
+ncm_cfg_exist_named_instance (gchar *name)
+{
+  g_assert (numcosmo_init);
+  g_assert (name != NULL);
+  return (g_hash_table_lookup (named_instances_name_ptr, name) != NULL);
+}
+
+/**
+ * ncm_cfg_count_named_instances:
+ * 
+ * FIXME
+ * 
+ * Returns: FIXME
+ */
+guint
+ncm_cfg_count_named_instance (void)
+{
+  g_assert (numcosmo_init);
+  return g_hash_table_size (named_instances_name_ptr);
+}
+
+/**
+ * ncm_cfg_get_named_instance:
+ * @name: FIXME
+ * 
+ * FIXME
+ * 
+ * Returns: (transfer full) (type GObject): FIXME
+ */
+gpointer
+ncm_cfg_get_named_instance (gchar *name)
+{
+  g_assert (numcosmo_init);
+  g_assert (name != NULL);
+  {
+    GObject *obj = g_hash_table_lookup (named_instances_name_ptr, name);
+    return g_object_ref (obj);
+  }
+}
+
+/**
+ * ncm_cfg_named_instance_peek_name:
+ * @obj: (type GObject): FIXME
+ * 
+ * FIXME
+ * 
+ * Returns: (transfer none): FIXME
+ */
+gchar *
+ncm_cfg_named_instance_peek_name (gpointer obj)
+{
+  g_assert (numcosmo_init);
+  g_assert (G_IS_OBJECT (obj));
+  if (!ncm_cfg_is_named_instance (obj))
+    g_error ("ncm_cfg_named_instance_peek_name: Cannot peek name of object %p, it is not a named instance.", obj);
+  else
+    return g_hash_table_lookup (named_instances_ptr_name, obj);
+}
+
+/**
+ * ncm_cfg_set_named_instance:
+ * @obj: (type GObject): FIXME
+ * @name: FIXME
+ * @overwrite: FIXME
+ * 
+ * FIXME
+ * 
+ */
+void 
+ncm_cfg_set_named_instance (gpointer obj, gchar *name, gboolean overwrite)
+{
+  g_assert (numcosmo_init);
+  g_assert (G_IS_OBJECT (obj));
+  g_assert (name != NULL);
+  {
+    gboolean ni_has_key = ncm_cfg_exist_named_instance (name);
+    if (!overwrite && ni_has_key)
+    {
+      gpointer ni_obj = ncm_cfg_get_named_instance (name);
+      if (ni_obj != obj)
+        g_error ("ncm_cfg_set_named_instance: named instance already present, set overwrite to true if you want it replaced.");
+      else
+      {
+        g_object_unref (ni_obj);
+        return;
+      }
+    }
+    g_hash_table_insert (named_instances_name_ptr, 
+                         g_strdup (name), g_object_ref (obj));
+    g_hash_table_insert (named_instances_ptr_name, 
+                         g_object_ref (obj), g_strdup (name));
+  }  
+}
+
+/**
+ * ncm_cfg_free_named_instances:
+ * 
+ * FIXME
+ * 
+ */
+void 
+ncm_cfg_free_named_instances (void)
+{
+  g_assert (numcosmo_init);
+  g_hash_table_remove_all (named_instances_name_ptr);
+  g_hash_table_remove_all (named_instances_ptr_name);
+}
+
+/**
+ * ncm_cfg_object_is_named:
+ * @serobj: FIXME
+ * @name: (out) (transfer full): FIXME 
+ * 
+ * FIXME
+ * 
+ * Returns: FIXME
+ */
+gboolean 
+ncm_cfg_object_is_named (const gchar *serobj, gchar **name)
+{
+  GError *error = NULL;
+  static gsize regex_init = FALSE;
+  static GRegex *regex = NULL;
+  GMatchInfo *match_info = NULL;
+  GVariant *var_obj = NULL;
+  GVariant *obj_name = NULL;
+  GVariant *params = NULL;
+
+  if (g_once_init_enter (&regex_init))
+  {
+    regex = g_regex_new ("^\\s*[A-Z][A-Za-z]+\\s*\\[([A-Za-z\\:]+)\\]\\s*$", 0, 0, &error);
+    g_once_init_leave (&regex_init, TRUE);
+  }
+
+  var_obj = g_variant_parse (G_VARIANT_TYPE ("{sa{sv}}"), serobj, NULL, NULL, &error);
+  g_clear_error (&error);
+
+  if (var_obj != NULL)
+  {
+    obj_name = g_variant_get_child_value (var_obj, 0);
+    params = g_variant_get_child_value (var_obj, 1);
+    serobj = g_variant_get_string (obj_name, NULL);
+  }
+
+  if (g_regex_match (regex, serobj, 0, &match_info))
+  {
+    *name = g_match_info_fetch (match_info, 1);
+    g_match_info_free (match_info);
+    if (params != NULL && g_variant_n_children (params) > 0)
+      g_error ("ncm_cfg_object_is_named: Invalid named object ``%s'', named objects cannot have properties ``%s''.", 
+               serobj, g_variant_print (params, TRUE));    
+
+    if (obj_name != NULL)
+      g_variant_unref (obj_name);
+    if (var_obj != NULL)
+      g_variant_unref (var_obj);
+    if (params != NULL)
+      g_variant_unref (params);
+    return TRUE;
+  }
+  else
+  {
+    if (obj_name != NULL)
+      g_variant_unref (obj_name);
+    if (var_obj != NULL)
+      g_variant_unref (var_obj);
+    if (params != NULL)
+      g_variant_unref (params);
+    *name = NULL;
+    return FALSE;
+  }
+}
+
 /**
  * ncm_cfg_get_fullpath:
  * @filename: FIXME
@@ -557,26 +773,65 @@ ncm_cfg_keyfile_to_arg (GKeyFile *kfile, gchar *group_name, GOptionEntry *entrie
     {
       if (g_key_file_has_key (kfile, group_name, entries[i].long_name, &error))
       {
-        gchar *val = g_key_file_get_value (kfile, group_name, entries[i].long_name, &error);
-        if (entries[i].arg == G_OPTION_ARG_NONE)
+        if (entries[i].arg == G_OPTION_ARG_STRING_ARRAY || entries[i].arg == G_OPTION_ARG_FILENAME_ARRAY)
         {
-          if ((g_ascii_strcasecmp (val, "1") == 0) ||
-              (g_ascii_strcasecmp (val, "true") == 0))
+          gint j;
+          gsize length;
+          gchar **vals = g_key_file_get_string_list (kfile, group_name, entries[i].long_name, &length, &error);
+          if (error != NULL)
+            g_error ("ncm_cfg_keyfile_to_arg: Cannot parse key file[%s]", error->message);
+          for (j = 0; j < length; j++)
           {
             argv[argc[0]++] = g_strdup_printf ("--%s", entries[i].long_name);
+            argv[argc[0]++] = vals[j];
           }
-          g_free (val);
+          g_free (vals);
         }
-        else if (strlen (val) > 0)
+        else
         {
-          argv[argc[0]++] = g_strdup_printf ("--%s", entries[i].long_name);
-          argv[argc[0]++] = val;
+          gchar *val = g_key_file_get_value (kfile, group_name, entries[i].long_name, &error);
+          if (error != NULL)
+            g_error ("ncm_cfg_keyfile_to_arg: Cannot parse key file[%s]", error->message);
+          if (entries[i].arg == G_OPTION_ARG_NONE)
+          {
+            if ((g_ascii_strcasecmp (val, "1") == 0) ||
+                (g_ascii_strcasecmp (val, "true") == 0))
+            {
+              argv[argc[0]++] = g_strdup_printf ("--%s", entries[i].long_name);
+            }
+            g_free (val);
+          }
+          else if (strlen (val) > 0)
+          {
+            argv[argc[0]++] = g_strdup_printf ("--%s", entries[i].long_name);
+            argv[argc[0]++] = val;
+          }
         }
       }
     }
   }
 }
 
+/**
+ * ncm_cfg_string_to_comment:
+ * @str: FIXME
+ * 
+ * FIXME
+ * 
+ * Returns: (transfer full): FIXME
+ */
+gchar *
+ncm_cfg_string_to_comment (const gchar *str)
+{
+  g_assert (str != NULL);
+  {
+    gchar *desc_ww = ncm_string_ww (str, "  ", "  ", 80);
+    gchar *desc = g_strdup_printf ("###############################################################################\n\n%s\n", desc_ww);
+    g_free (desc_ww);
+    return desc;
+  }
+}
+
 /**
  * ncm_cfg_entries_to_keyfile:
  * @kfile: FIXME
@@ -649,17 +904,14 @@ ncm_cfg_entries_to_keyfile (GKeyFile *kfile, gchar *group_name, GOptionEntry *en
     }
     if (!skip_comment)
     {
-      gchar *desc_ww = ncm_string_ww (entries[i].description, "  ", "  ", 80);
-      gchar *desc = g_strdup_printf ("###############################################################################\n\n%s\n", desc_ww);
+      gchar *desc = ncm_cfg_string_to_comment (entries[i].description); 
       if (!g_key_file_set_comment (kfile, group_name, entries[i].long_name, desc, &error))
         g_error ("ncm_cfg_entries_to_keyfile: %s", error->message);
       g_free (desc);
-      g_free (desc_ww);
     }
   }
 }
 
-
 /**
  * ncm_cfg_get_enum_by_id_name_nick:
  * @enum_type: FIXME
@@ -1365,6 +1617,297 @@ ncm_cfg_command_line (gchar *argv[], gint argc)
   return full_cmd_line;
 }
 
+/* Stole from glib 2.36.1 */
+/* GDBus - GLib D-Bus Library
+ *
+ * Copyright (C) 2008-2010 Red Hat, Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
+ *
+ * Author: David Zeuthen <davidz@redhat.com>
+ */
+#if ((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
+
+#define G_VARIANT_TYPE_VARDICT              ((const GVariantType *) "a{sv}")
+
+static void
+g_dbus_gvariant_to_gvalue (GVariant *value, GValue *out_gvalue)
+{
+  const GVariantType *type;
+  gchar **array;
+
+  g_return_if_fail (value != NULL);
+  g_return_if_fail (out_gvalue != NULL);
+
+  memset (out_gvalue, '\0', sizeof (GValue));
+
+  switch (g_variant_classify (value))
+  {
+    case G_VARIANT_CLASS_BOOLEAN:
+      g_value_init (out_gvalue, G_TYPE_BOOLEAN);
+      g_value_set_boolean (out_gvalue, g_variant_get_boolean (value));
+      break;
+
+    case G_VARIANT_CLASS_BYTE:
+      g_value_init (out_gvalue, G_TYPE_UCHAR);
+      g_value_set_uchar (out_gvalue, g_variant_get_byte (value));
+      break;
+
+    case G_VARIANT_CLASS_INT16:
+      g_value_init (out_gvalue, G_TYPE_INT);
+      g_value_set_int (out_gvalue, g_variant_get_int16 (value));
+      break;
+
+    case G_VARIANT_CLASS_UINT16:
+      g_value_init (out_gvalue, G_TYPE_UINT);
+      g_value_set_uint (out_gvalue, g_variant_get_uint16 (value));
+      break;
+
+    case G_VARIANT_CLASS_INT32:
+      g_value_init (out_gvalue, G_TYPE_INT);
+      g_value_set_int (out_gvalue, g_variant_get_int32 (value));
+      break;
+
+    case G_VARIANT_CLASS_UINT32:
+      g_value_init (out_gvalue, G_TYPE_UINT);
+      g_value_set_uint (out_gvalue, g_variant_get_uint32 (value));
+      break;
+
+    case G_VARIANT_CLASS_INT64:
+      g_value_init (out_gvalue, G_TYPE_INT64);
+      g_value_set_int64 (out_gvalue, g_variant_get_int64 (value));
+      break;
+
+    case G_VARIANT_CLASS_UINT64:
+      g_value_init (out_gvalue, G_TYPE_UINT64);
+      g_value_set_uint64 (out_gvalue, g_variant_get_uint64 (value));
+      break;
+
+    case G_VARIANT_CLASS_DOUBLE:
+      g_value_init (out_gvalue, G_TYPE_DOUBLE);
+      g_value_set_double (out_gvalue, g_variant_get_double (value));
+      break;
+
+    case G_VARIANT_CLASS_STRING:
+      g_value_init (out_gvalue, G_TYPE_STRING);
+      g_value_set_string (out_gvalue, g_variant_get_string (value, NULL));
+      break;
+
+    case G_VARIANT_CLASS_OBJECT_PATH:
+      g_value_init (out_gvalue, G_TYPE_STRING);
+      g_value_set_string (out_gvalue, g_variant_get_string (value, NULL));
+      break;
+
+    case G_VARIANT_CLASS_SIGNATURE:
+      g_value_init (out_gvalue, G_TYPE_STRING);
+      g_value_set_string (out_gvalue, g_variant_get_string (value, NULL));
+      break;
+
+    case G_VARIANT_CLASS_ARRAY:
+      type = g_variant_get_type (value);
+      switch (g_variant_type_peek_string (type)[1])
+    {
+      case G_VARIANT_CLASS_BYTE:
+        g_value_init (out_gvalue, G_TYPE_STRING);
+        g_value_set_string (out_gvalue, g_variant_get_bytestring (value));
+        break;
+
+      case G_VARIANT_CLASS_STRING:
+        g_value_init (out_gvalue, G_TYPE_STRV);
+        array = g_variant_dup_strv (value, NULL);
+        g_value_take_boxed (out_gvalue, array);
+        break;
+
+      case G_VARIANT_CLASS_ARRAY:
+        switch (g_variant_type_peek_string (type)[2])
+      {
+        case G_VARIANT_CLASS_BYTE:
+          g_value_init (out_gvalue, G_TYPE_STRV);
+          array = g_variant_dup_bytestring_array (value, NULL);
+          g_value_take_boxed (out_gvalue, array);
+          break;
+
+        default:
+          g_value_init (out_gvalue, G_TYPE_VARIANT);
+          g_value_set_variant (out_gvalue, value);
+          break;
+      }
+        break;
+
+      default:
+        g_value_init (out_gvalue, G_TYPE_VARIANT);
+        g_value_set_variant (out_gvalue, value);
+        break;
+    }
+      break;
+
+    case G_VARIANT_CLASS_HANDLE:
+    case G_VARIANT_CLASS_VARIANT:
+    case G_VARIANT_CLASS_MAYBE:
+    case G_VARIANT_CLASS_TUPLE:
+    case G_VARIANT_CLASS_DICT_ENTRY:
+      g_value_init (out_gvalue, G_TYPE_VARIANT);
+      g_value_set_variant (out_gvalue, value);
+      break;
+  }
+}
+
+static GVariant *
+g_dbus_gvalue_to_gvariant (const GValue *gvalue, const GVariantType *type)
+{
+  GVariant *ret;
+  const gchar *s;
+  const gchar * const *as;
+  const gchar *empty_strv[1] = {NULL};
+
+  g_return_val_if_fail (gvalue != NULL, NULL);
+  g_return_val_if_fail (type != NULL, NULL);
+
+  ret = NULL;
+
+  if (G_VALUE_TYPE (gvalue) == G_TYPE_VARIANT)
+  {
+    ret = g_value_dup_variant (gvalue);
+  }
+  else
+  {
+    switch (g_variant_type_peek_string (type)[0])
+    {
+      case G_VARIANT_CLASS_BOOLEAN:
+        ret = g_variant_ref_sink (g_variant_new_boolean (g_value_get_boolean (gvalue)));
+        break;
+
+      case G_VARIANT_CLASS_BYTE:
+        ret = g_variant_ref_sink (g_variant_new_byte (g_value_get_uchar (gvalue)));
+        break;
+
+      case G_VARIANT_CLASS_INT16:
+        ret = g_variant_ref_sink (g_variant_new_int16 (g_value_get_int (gvalue)));
+        break;
+
+      case G_VARIANT_CLASS_UINT16:
+        ret = g_variant_ref_sink (g_variant_new_uint16 (g_value_get_uint (gvalue)));
+        break;
+
+      case G_VARIANT_CLASS_INT32:
+        ret = g_variant_ref_sink (g_variant_new_int32 (g_value_get_int (gvalue)));
+        break;
+
+      case G_VARIANT_CLASS_UINT32:
+        ret = g_variant_ref_sink (g_variant_new_uint32 (g_value_get_uint (gvalue)));
+        break;
+
+      case G_VARIANT_CLASS_INT64:
+        ret = g_variant_ref_sink (g_variant_new_int64 (g_value_get_int64 (gvalue)));
+        break;
+
+      case G_VARIANT_CLASS_UINT64:
+        ret = g_variant_ref_sink (g_variant_new_uint64 (g_value_get_uint64 (gvalue)));
+        break;
+
+      case G_VARIANT_CLASS_DOUBLE:
+        ret = g_variant_ref_sink (g_variant_new_double (g_value_get_double (gvalue)));
+        break;
+
+      case G_VARIANT_CLASS_STRING:
+        s = g_value_get_string (gvalue);
+        if (s == NULL)
+          s = "";
+        ret = g_variant_ref_sink (g_variant_new_string (s));
+        break;
+
+      case G_VARIANT_CLASS_OBJECT_PATH:
+        s = g_value_get_string (gvalue);
+        if (s == NULL)
+          s = "/";
+        ret = g_variant_ref_sink (g_variant_new_object_path (s));
+        break;
+
+      case G_VARIANT_CLASS_SIGNATURE:
+        s = g_value_get_string (gvalue);
+        if (s == NULL)
+          s = "";
+        ret = g_variant_ref_sink (g_variant_new_signature (s));
+        break;
+
+      case G_VARIANT_CLASS_ARRAY:
+        switch (g_variant_type_peek_string (type)[1])
+      {
+        case G_VARIANT_CLASS_BYTE:
+          s = g_value_get_string (gvalue);
+          if (s == NULL)
+            s = "";
+          ret = g_variant_ref_sink (g_variant_new_bytestring (s));
+          break;
+
+        case G_VARIANT_CLASS_STRING:
+          as = g_value_get_boxed (gvalue);
+          if (as == NULL)
+            as = empty_strv;
+          ret = g_variant_ref_sink (g_variant_new_strv (as, -1));
+          break;
+
+        case G_VARIANT_CLASS_ARRAY:
+          switch (g_variant_type_peek_string (type)[2])
+        {
+          case G_VARIANT_CLASS_BYTE:
+            as = g_value_get_boxed (gvalue);
+            if (as == NULL)
+              as = empty_strv;
+            ret = g_variant_ref_sink (g_variant_new_bytestring_array (as, -1));
+            break;
+
+          default:
+            ret = g_value_dup_variant (gvalue);
+            break;
+        }
+          break;
+
+        default:
+          ret = g_value_dup_variant (gvalue);
+          break;
+      }
+        break;
+
+      case G_VARIANT_CLASS_HANDLE:
+      case G_VARIANT_CLASS_VARIANT:
+      case G_VARIANT_CLASS_MAYBE:
+      case G_VARIANT_CLASS_TUPLE:
+      case G_VARIANT_CLASS_DICT_ENTRY:
+        ret = g_value_dup_variant (gvalue);
+        break;
+    }
+  }
+
+  if (ret == NULL)
+  {
+    GVariant *untrusted_empty;
+    untrusted_empty = g_variant_new_from_data (type, NULL, 0, FALSE, NULL, NULL);
+    ret = g_variant_ref_sink (g_variant_get_normal_form (untrusted_empty));
+    g_variant_unref (untrusted_empty);
+  }
+
+  g_assert (!g_variant_is_floating (ret));
+
+  return ret;
+}
+
+#endif
+/* Stole from glib 2.36.1 */
+
 /**
  * ncm_cfg_set_params:
  * @obj: a #GObject.
@@ -1375,7 +1918,6 @@ ncm_cfg_command_line (gchar *argv[], gint argc)
  */
 void
 ncm_cfg_object_set_property (GObject *obj, const gchar *prop_str)
-#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   GError *error = NULL;
   GVariant *params = g_variant_parse (G_VARIANT_TYPE_VARDICT, prop_str, NULL, NULL, &error);
@@ -1425,12 +1967,6 @@ ncm_cfg_object_set_property (GObject *obj, const gchar *prop_str)
     g_variant_iter_free (p_iter);
   }
 }
-#else
-{
-  g_error ("ncm_cfg_object_set_property: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
-  return NULL;
-}
-#endif
 
 /**
  * ncm_cfg_create_from_string:
@@ -1442,7 +1978,6 @@ ncm_cfg_object_set_property (GObject *obj, const gchar *prop_str)
  */
 GObject *
 ncm_cfg_create_from_string (const gchar *obj_ser)
-#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   GError *error = NULL;
   static gsize regex_init = FALSE;
@@ -1450,13 +1985,24 @@ ncm_cfg_create_from_string (const gchar *obj_ser)
   GMatchInfo *match_info = NULL;
   GObject *obj = NULL;
   GVariant *var_obj = NULL;
+  gchar *ni_name = NULL;
 
   if (g_once_init_enter (&regex_init))
   {
-    regex = g_regex_new ("^\\s*([A-Z][A-Za-z]*)\\s*(.*?)\\s*$", 0, 0, &error);
+    regex = g_regex_new ("^\\s*([A-Z][A-Za-z]+)\\s*([\\{]?.*[\\}]?)\\s*$", 0, 0, &error);
     g_once_init_leave (&regex_init, TRUE);
   }
 
+  if (ncm_cfg_object_is_named (obj_ser, &ni_name))
+  {
+    if (ncm_cfg_exist_named_instance (ni_name))
+      g_error ("ncm_cfg_create_from_string: Creating object from ``%s'', depending named instance ``%s'' not found.", 
+               obj_ser, ni_name);
+    obj = ncm_cfg_get_named_instance (ni_name);
+    g_free (ni_name);
+    return obj;
+  }
+
   var_obj = g_variant_parse (G_VARIANT_TYPE ("{sa{sv}}"), obj_ser, NULL, NULL, &error);
   g_clear_error (&error);
   if (var_obj != NULL)
@@ -1464,6 +2010,7 @@ ncm_cfg_create_from_string (const gchar *obj_ser)
     GVariant *obj_name = g_variant_get_child_value (var_obj, 0);
     GVariant *params = g_variant_get_child_value (var_obj, 1);
     obj = ncm_cfg_create_from_name_params (g_variant_get_string (obj_name, NULL), params);
+    
     g_variant_unref (obj_name);
     g_variant_unref (params);
     g_variant_unref (var_obj);
@@ -1500,12 +2047,6 @@ ncm_cfg_create_from_string (const gchar *obj_ser)
 
   return obj;
 }
-#else
-{
-  g_error ("ncm_cfg_create_from_string: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
-  return NULL;
-}
-#endif
 
 /**
  * ncm_cfg_create_from_name_params:
@@ -1518,10 +2059,25 @@ ncm_cfg_create_from_string (const gchar *obj_ser)
  */
 GObject *
 ncm_cfg_create_from_name_params (const gchar *obj_name, GVariant *params)
-#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   GObject *obj = NULL;
   GType gtype = g_type_from_name (obj_name);
+  gchar *ni_name;
+
+  if (ncm_cfg_object_is_named (obj_name, &ni_name))
+  {
+    if (!ncm_cfg_exist_named_instance (ni_name))
+      g_error ("ncm_cfg_create_from_string: Creating object from ``%s'', depending named instance ``%s'' not found.", 
+               obj_name, ni_name);
+    if (params != NULL && g_variant_n_children (params) > 0)
+      g_error ("ncm_cfg_create_from_name_params: Invalid named object parameters ``%s'', named objects cannot have properties.", 
+               g_variant_print (params, TRUE));    
+
+    obj = ncm_cfg_get_named_instance (ni_name);
+
+    g_free (ni_name);
+    return obj;
+  }
 
   if (gtype == 0)
     g_error ("Object '%s' is not registered\n", obj_name);
@@ -1577,14 +2133,7 @@ ncm_cfg_create_from_name_params (const gchar *obj_name, GVariant *params)
 
   return obj;
 }
-#else
-{
-  g_error ("ncm_cfg_create_from_name_params: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
-  return NULL;
-}
-#endif
 
-#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 static const GVariantType *
 _ncm_cfg_gtype_to_gvariant_type (GType t)
 {
@@ -1694,7 +2243,6 @@ _ncm_cfg_gtype_to_gvariant_type (GType t)
       break;
   }
 }
-#endif
 
 /**
  * ncm_cfg_gvalue_to_gvariant:
@@ -1706,7 +2254,6 @@ _ncm_cfg_gtype_to_gvariant_type (GType t)
    */
 GVariant *
 ncm_cfg_gvalue_to_gvariant (GValue *val)
-#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   GType t = G_VALUE_TYPE (val);
   GType fund_t = G_TYPE_FUNDAMENTAL (t);
@@ -1731,7 +2278,7 @@ ncm_cfg_gvalue_to_gvariant (GValue *val)
         var = g_variant_ref_sink (g_variant_new_uint32 (g_value_get_flags (val)));
         break;
       default:
-        g_error ("Cannot covert GValue '%s' to GVariant.", g_type_name (t));
+        g_error ("Cannot convert GValue '%s' to GVariant.", g_type_name (t));
         break;
     }
   }
@@ -1740,12 +2287,6 @@ ncm_cfg_gvalue_to_gvariant (GValue *val)
 
   return var;
 }
-#else
-{
-  g_error ("ncm_cfg_gvalue_to_gvariant: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
-  return NULL;
-}
-#endif
 
 /**
  * ncm_cfg_serialize_to_variant:
@@ -1757,63 +2298,67 @@ ncm_cfg_gvalue_to_gvariant (GValue *val)
    */
 GVariant *
 ncm_cfg_serialize_to_variant (GObject *obj)
-#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   const gchar *obj_name = G_OBJECT_TYPE_NAME (obj);
-  GObjectClass *klass = G_OBJECT_GET_CLASS (obj);
-  guint n_properties, i;
-  GParamSpec **prop = g_object_class_list_properties (klass, &n_properties);
-
-  if (n_properties == 0)
+  if (ncm_cfg_is_named_instance (obj))
   {
-    g_free (prop);
-    return g_variant_ref_sink (g_variant_new ("{sa{sv}}", obj_name, NULL));
+    gchar *ni_name = ncm_cfg_named_instance_peek_name (obj);
+    gchar *fname = g_strdup_printf ("%s[%s]", obj_name, ni_name);
+    GVariant *objvar = g_variant_ref_sink (g_variant_new ("{sa{sv}}", fname, NULL));
+    g_free (fname);
+    return objvar;
   }
   else
   {
-    GVariantBuilder b;
-    GVariant *params, *ser_var;
+    GObjectClass *klass = G_OBJECT_GET_CLASS (obj);
+    guint n_properties, i;
+    GParamSpec **prop = g_object_class_list_properties (klass, &n_properties);
 
-    g_variant_builder_init (&b, G_VARIANT_TYPE ("a{sv}"));
-
-    for (i = 0; i < n_properties; i++)
+    if (n_properties == 0)
     {
-      GVariant *var = NULL;
-      GValue val = G_VALUE_INIT;
+      g_free (prop);
+      return g_variant_ref_sink (g_variant_new ("{sa{sv}}", obj_name, NULL));
+    }
+    else
+    {
+      GVariantBuilder b;
+      GVariant *params, *ser_var;
 
-      if (!(prop[i]->flags & G_PARAM_WRITABLE))
-        continue;
+      g_variant_builder_init (&b, G_VARIANT_TYPE ("a{sv}"));
 
-      g_value_init (&val, prop[i]->value_type);
-      g_object_get_property (obj, prop[i]->name, &val);
-
-      var = ncm_cfg_gvalue_to_gvariant (&val);
-      if (var == NULL)
+      for (i = 0; i < n_properties; i++)
       {
+        GVariant *var = NULL;
+        GValue val = G_VALUE_INIT;
+
+        if ((prop[i]->flags & G_PARAM_READWRITE) != G_PARAM_READWRITE)
+          continue;
+
+        g_value_init (&val, prop[i]->value_type);
+        g_object_get_property (obj, prop[i]->name, &val);
+
+        var = ncm_cfg_gvalue_to_gvariant (&val);
+        if (var == NULL)
+        {
+          g_value_unset (&val);
+          continue;
+        }
+
+        g_variant_builder_add (&b, "{sv}", prop[i]->name, var);
+
+        g_variant_unref (var);
         g_value_unset (&val);
-        continue;
       }
 
-      g_variant_builder_add (&b, "{sv}", prop[i]->name, var);
+      params = g_variant_builder_end (&b);
 
-      g_variant_unref (var);
-      g_value_unset (&val);
+      g_free (prop);
+
+      ser_var = g_variant_ref_sink (g_variant_new ("{s@a{sv}}", obj_name, params));
+      return ser_var;
     }
-
-    params = g_variant_builder_end (&b);
-
-    g_free (prop);
-
-    ser_var = g_variant_ref_sink (g_variant_new ("{s@a{sv}}", obj_name, params));
-    return ser_var;
   }
 }
-#else
-{
-  g_error ("ncm_cfg_serialize_to_variant: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
-  return NULL;
-}
-#endif
 
 /**
  * ncm_cfg_serialize_to_string:
@@ -1827,7 +2372,6 @@ ncm_cfg_serialize_to_variant (GObject *obj)
    */
 gchar *
 ncm_cfg_serialize_to_string (GObject *obj, gboolean valid_variant)
-#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   GVariant *ser_var = ncm_cfg_serialize_to_variant (obj);
   gchar *ser = NULL;
@@ -1848,19 +2392,11 @@ ncm_cfg_serialize_to_string (GObject *obj, gboolean valid_variant)
     {
       params_str = g_variant_print (params, TRUE);
       ser = g_strdup_printf ("%s%s", obj_name, params_str);
-      g_free (params_str);
-      g_free (obj_name);
+      g_free (params_str);  
     }
+    g_free (obj_name);
     g_variant_unref (params);
   }
   g_variant_unref (ser_var);
   return ser;
 }
-#else
-{
-  g_error ("ncm_cfg_serialize_to_string: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
-  return NULL;
-}
-#endif
-
- 
\ No newline at end of file
