@@ -28,6 +28,7 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <glib-object.h>
+#include <numcosmo/build_cfg.h>
 #include <stdio.h>
 #include <gsl/gsl_vector.h>
 #include <gsl/gsl_matrix.h>
@@ -46,6 +47,7 @@ void ncm_cfg_register_obj (GType obj);
 gchar *ncm_cfg_get_fullpath (const gchar *filename, ...);
 void ncm_cfg_keyfile_to_arg (GKeyFile *kfile, gchar *group_name, GOptionEntry *entries, gchar **argv, gint *argc);
 void ncm_cfg_entries_to_keyfile (GKeyFile *kfile, gchar *group_name, GOptionEntry *entries);
+gchar *ncm_cfg_string_to_comment (const gchar *str);
 const GEnumValue *ncm_cfg_get_enum_by_id_name_nick (GType enum_type, const gchar *id_name_nick);
 void ncm_cfg_enum_print_all (GType enum_type, gchar *header);
 
@@ -66,6 +68,15 @@ gsl_rng *ncm_cfg_rng_get (void);
 gchar *ncm_cfg_rng_get_state (void);
 void ncm_cfg_rng_set_state (gchar *state);
 
+gboolean ncm_cfg_is_named_instance (gpointer obj);
+gboolean ncm_cfg_exist_named_instance (gchar *name);
+guint ncm_cfg_count_named_instance (void);
+gpointer ncm_cfg_get_named_instance (gchar *name);
+gchar *ncm_cfg_named_instance_peek_name (gpointer obj);
+void ncm_cfg_set_named_instance (gpointer obj, gchar *name, gboolean overwrite);
+void ncm_cfg_free_named_instances (void);
+gboolean ncm_cfg_object_is_named (const gchar *serobj, gchar **name);
+
 FILE *ncm_cfg_fopen (gchar *filename, gchar *mode, ...);
 FILE *ncm_cfg_vfopen (gchar *filename, gchar *mode, va_list ap);
 
@@ -230,6 +241,11 @@ do { \
 
 #define NCM_READ_DOUBLE(_ff,_ii) do { NcmDoubleInt64 _iii; if (fread (&_iii.i, sizeof(gint64), (1), _ff) != 1) g_error ("NCM_READ_DOUBLE: io error"); _iii.i = GINT64_FROM_BE (_iii.i); _ii = _iii.x; } while (FALSE)
 
+/* Workaround on g_clear_object. */
+#if ((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 28))
+#define g_clear_object(obj) G_STMT_START if (*(obj) != NULL) { g_object_unref (*(obj)); *(obj) = NULL; }  G_STMT_END
+#endif /* Glib version < 2.28 */
+
 G_END_DECLS
 
 #endif /* _NCM_CFG_H */
