@@ -28,6 +28,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <numcosmo/build_cfg.h>
 #include <numcosmo/math/ncm_model.h>
 
 #include <stdio.h>
@@ -46,13 +47,25 @@ G_BEGIN_DECLS
 typedef struct _NcmMSetClass NcmMSetClass;
 typedef struct _NcmMSet NcmMSet;
 typedef struct _NcmMSetPIndex NcmMSetPIndex;
+typedef struct _NcmMSetModelDesc NcmMSetModelDesc; 
 
 #define NCM_MODEL_MAX_ID 5
 
+struct _NcmMSetModelDesc
+{
+  /*< private >*/
+  gboolean init;
+  gchar *ns;
+  gchar *desc;
+  gchar *long_desc;
+};
+
 struct _NcmMSetClass
 {
   /*< private >*/
   GObjectClass parent_class;
+  GHashTable *ns_table;
+  NcmMSetModelDesc model_desc[NCM_MODEL_MAX_ID];
 };
 
 struct _NcmMSet
@@ -77,6 +90,47 @@ struct _NcmMSetPIndex
 GType ncm_mset_get_type (void) G_GNUC_CONST;
 GType ncm_mset_pindex_get_type (void) G_GNUC_CONST;
 
+void ncm_mset_model_register_id (NcmModelClass *model_class, gchar *ns, gchar *desc, gchar *long_desc);
+
+/**
+ * NCM_MSET_MODEL_ID_FUNC: (skip)
+ * @model_ns: FIXME
+ * 
+ * FIXME
+ * 
+ */
+#define NCM_MSET_MODEL_ID_FUNC(model_ns) model_ns##_id
+
+/**
+ * NCM_MSET_MODEL_DECLARE_ID: (skip)
+ * @model_ns: FIXME
+ * 
+ * FIXME
+ * 
+ */
+#define NCM_MSET_MODEL_DECLARE_ID(model_ns) gint32 NCM_MSET_MODEL_ID_FUNC(model_ns) (void) G_GNUC_CONST
+
+/**
+ * NCM_MSET_MODEL_REGISTER_ID: (skip)
+ * @model_ns: FIXME
+ * @typemacro: FIXME
+ * 
+ * FIXME
+ * 
+ */
+#define NCM_MSET_MODEL_REGISTER_ID(model_ns,typemacro) \
+gint32 NCM_MSET_MODEL_ID_FUNC(model_ns) (void) \
+{ \
+  static gint32 id = -1; \
+  if (id == -1) \
+  { \
+    NcmModelClass *model_class = g_type_class_ref (typemacro); \
+    id = model_class->model_id; \
+    g_type_class_unref (model_class); \
+  } \
+  return id; \
+}
+
 NcmMSetPIndex *ncm_mset_pindex_new (NcmModelID mid, guint pid);
 NcmMSetPIndex *ncm_mset_pindex_dup (NcmMSetPIndex *pi);
 void ncm_mset_pindex_free (NcmMSetPIndex *pi);
@@ -97,6 +151,7 @@ NcmModel *ncm_mset_peek (NcmMSet *mset, NcmModelID mid);
 NcmModel *ncm_mset_get (NcmMSet *mset, NcmModelID mid);
 void ncm_mset_remove (NcmMSet *mset, NcmModelID mid);
 void ncm_mset_set (NcmMSet *mset, NcmModel *model);
+gboolean ncm_mset_exists (NcmMSet *mset, NcmModel *model);
 
 void ncm_mset_prepare_fparam_map (NcmMSet *mset);
 
@@ -150,6 +205,9 @@ void ncm_mset_fparam_set (NcmMSet *mset, guint n, const gdouble x);
 NcmMSetPIndex *ncm_mset_fparam_get_pi (NcmMSet *mset, guint n);
 gint ncm_mset_fparam_get_fpi (NcmMSet *mset, NcmModelID mid, guint pid);
 
+void ncm_mset_save (NcmMSet *mset, gchar *filename, gboolean save_comment);
+NcmMSet *ncm_mset_load (gchar *filename);
+
 G_END_DECLS
 
 #endif /* _NCM_MSET_H_ */
