@@ -28,6 +28,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <numcosmo/build_cfg.h>
 #include <numcosmo/math/ncm_mset.h>
 
 G_BEGIN_DECLS
@@ -69,8 +70,15 @@ void ncm_mset_func_free (NcmMSetFunc *func);
 
 GPtrArray *ncm_mset_func_array_new (void);
 
+gdouble ncm_mset_func_eval (NcmMSetFunc *func, NcmMSet *mset, const gdouble *x);
 gdouble ncm_mset_func_eval0 (NcmMSetFunc *func, NcmMSet *mset);
 gdouble ncm_mset_func_eval1 (NcmMSetFunc *func, NcmMSet *mset, const gdouble x);
+gboolean ncm_mset_func_is_scalar (NcmMSetFunc *func);
+gboolean ncm_mset_func_is_vector (NcmMSetFunc *func, guint dim);
+gboolean ncm_mset_func_is_const (NcmMSetFunc *func);
+gboolean ncm_mset_func_has_params (NcmMSetFunc *func, guint np);
+
+NcmVector *ncm_mset_func_numdiff_fparams (NcmMSetFunc *func, NcmMSet *mset, const gdouble *x, NcmVector *out);
 
 G_END_DECLS
 
