@@ -38,6 +38,7 @@
 #include "build_cfg.h"
 
 #include "math/ncm_spline.h"
+#include "math/ncm_cfg.h"
 
 G_DEFINE_ABSTRACT_TYPE (NcmSpline, ncm_spline, G_TYPE_OBJECT);
 
@@ -94,8 +95,8 @@ ncm_spline_new (const NcmSpline *s, NcmVector *xv, NcmVector *yv, gboolean init)
 /**
  * ncm_spline_new_array:
  * @s: a constant #NcmSpline.
- * @x: GArray of knots.
- * @y: GArray of the values of the function, to be interpolated, computed at @x.
+ * @x: (element-type double): GArray of knots.
+ * @y: (element-type double): GArray of the values of the function, to be interpolated, computed at @x.
  * @init: TRUE to prepare the new #NcmSpline or FALSE to not prepare it.
  *
  * This function returns a new #NcmSpline, where the knots of this new spline are given
@@ -153,7 +154,7 @@ ncm_spline_set (NcmSpline *s, NcmVector *xv, NcmVector *yv, gboolean init)
 	if (ncm_vector_len (xv) != ncm_vector_len (yv))
 		g_error ("ncm_spline_set: knot and function values vector has not the same size");
 	if (ncm_vector_len (xv) < NCM_SPLINE_GET_CLASS (s)->min_size (s))
-		g_error ("ncm_spline_set: min size for [%s] is %zu but vector size is %u", NCM_SPLINE_GET_CLASS (s)->name,
+		g_error ("ncm_spline_set: min size for [%s] is %zu but vector size is %u", NCM_SPLINE_GET_CLASS (s)->name (s),
 		         NCM_SPLINE_GET_CLASS (s)->min_size (s), ncm_vector_len (xv));
 
 	if (s->xv != NULL)
@@ -246,8 +247,8 @@ ncm_spline_set_yv (NcmSpline *s, NcmVector *yv, gboolean init)
 /**
  * ncm_spline_set_array:
  * @s: a #NcmSpline.
- * @x: GArray of knots.
- * @y: GArray of the values of the function, to be interpolated, computed at @x.
+ * @x: (element-type double): GArray of knots.
+ * @y: (element-type double): GArray of the values of the function, to be interpolated, computed at @x.
  * @init: TRUE to prepare @s or FALSE to not prepare it.
  *
  * This function sets @x as the knot vector and @y as the function values vector
@@ -357,6 +358,14 @@ ncm_spline_get_yv (NcmSpline *s)
  *
  * Returns: The second derivative of an interpolated function computed at @x.
  */
+/**
+ * ncm_spline_eval_deriv_nmax:
+ * @s: a constant #NcmSpline.
+ * @x: x-coordinate value.
+ *
+ *
+ * Returns: The highest non null derivative of an interpolated function computed at @x.
+ */
 /**
  * ncm_spline_eval_integ:
  * @s: a constant #NcmSpline.
