@@ -27,6 +27,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <numcosmo/build_cfg.h>
 #include <gsl/gsl_spline.h>
 #include <numcosmo/math/ncm_vector.h>
 
@@ -46,7 +47,7 @@ struct _NcmSplineClass
 {
   /*< private >*/
 	GObjectClass parent_class;
-	gchar *name;
+	const gchar *(*name) (NcmSpline *s);
 	void (*reset) (NcmSpline *s);
 	void (*prepare) (NcmSpline *s);
 	void (*prepare_base) (NcmSpline *s);
@@ -54,6 +55,7 @@ struct _NcmSplineClass
 	gdouble (*eval) (const NcmSpline *s, const gdouble x);
 	gdouble (*deriv) (const NcmSpline *s, const gdouble x);
 	gdouble (*deriv2) (const NcmSpline *s, const gdouble x);
+  gdouble (*deriv_nmax) (const NcmSpline *s, const gdouble x);
 	gdouble (*integ) (const NcmSpline *s, const gdouble xi, const gdouble xf);
 	NcmSpline *(*copy_empty) (const NcmSpline *s);
 };
@@ -97,6 +99,7 @@ G_INLINE_FUNC void ncm_spline_prepare_base (NcmSpline *s);
 G_INLINE_FUNC gdouble ncm_spline_eval (const NcmSpline *s, const gdouble x);
 G_INLINE_FUNC gdouble ncm_spline_eval_deriv (const NcmSpline *s, const gdouble x);
 G_INLINE_FUNC gdouble ncm_spline_eval_deriv2 (const NcmSpline *s, const gdouble x);
+G_INLINE_FUNC gdouble ncm_spline_eval_deriv_nmax (const NcmSpline *s, const gdouble x);
 G_INLINE_FUNC gdouble ncm_spline_eval_integ (const NcmSpline *s, const gdouble x0, const gdouble x1);
 G_INLINE_FUNC gboolean ncm_spline_is_empty (const NcmSpline *s);
 G_INLINE_FUNC gsize ncm_spline_min_size (const NcmSpline *s);
@@ -148,6 +151,12 @@ ncm_spline_eval_deriv2 (const NcmSpline *s, const gdouble x)
   return NCM_SPLINE_GET_CLASS (s)->deriv2 (s, x);
 }
 
+G_INLINE_FUNC gdouble
+ncm_spline_eval_deriv_nmax (const NcmSpline *s, const gdouble x)
+{
+  return NCM_SPLINE_GET_CLASS (s)->deriv_nmax (s, x);
+}
+
 G_INLINE_FUNC gdouble
 ncm_spline_eval_integ (const NcmSpline *s, const gdouble x0, const gdouble x1)
 {
