@@ -27,6 +27,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <numcosmo/build_cfg.h>
 #include <numcosmo/math/ncm_spline.h>
 
 G_BEGIN_DECLS
@@ -41,6 +42,28 @@ G_BEGIN_DECLS
 typedef struct _NcmSplineGslClass NcmSplineGslClass;
 typedef struct _NcmSplineGsl NcmSplineGsl;
 
+/**
+ * NcmSplineGslType:
+ * @NCM_SPLINE_GSL_LINEAR: FIXME
+ * @NCM_SPLINE_GSL_POLYNOMIAL: FIXME
+ * @NCM_SPLINE_GSL_CSPLINE: FIXME
+ * @NCM_SPLINE_GSL_CSPLINE_PERIODIC: FIXME
+ * @NCM_SPLINE_GSL_AKIMA: FIXME
+ * @NCM_SPLINE_GSL_AKIMA_PERIODIC: FIXME
+ *
+ * FIXME
+ */
+typedef enum _NcmSplineGslType
+{
+  NCM_SPLINE_GSL_LINEAR = 0,
+  NCM_SPLINE_GSL_POLYNOMIAL,
+  NCM_SPLINE_GSL_CSPLINE,
+  NCM_SPLINE_GSL_CSPLINE_PERIODIC,
+  NCM_SPLINE_GSL_AKIMA,
+  NCM_SPLINE_GSL_AKIMA_PERIODIC, /*< private >*/
+  NCM_SPLINE_GSL_TYPES_LEN,      /*< skip >*/
+} NcmSplineGslType;
+
 struct _NcmSplineGslClass
 {
   /*< private >*/
@@ -52,6 +75,8 @@ struct _NcmSplineGsl
   /*< private >*/
   NcmSpline parent_instance;
   gsl_interp *interp;
+  NcmSplineGslType type_id;
+  gchar *inst_name;
   const gsl_interp_type *type;
 };
 
@@ -60,6 +85,7 @@ GType ncm_spline_gsl_get_type (void) G_GNUC_CONST;
 NcmSpline *ncm_spline_gsl_new (const gsl_interp_type *type);
 NcmSpline *ncm_spline_gsl_new_full (const gsl_interp_type *type, NcmVector *xv, NcmVector *yv, gboolean init);
 void ncm_spline_gsl_set_type (NcmSplineGsl *sg, const gsl_interp_type *type);
+void ncm_spline_gsl_set_type_by_id (NcmSplineGsl *sg, NcmSplineGslType type_id);
 
 G_END_DECLS
 
