@@ -24,10 +24,11 @@
 
 /**
  * SECTION:nc_hicosmo_de_xcdm
- * @title: XCDM Darkenergy Model
- * @short_description: FIXME
+ * @title: Dark Energy -- XCDM
+ * @short_description: Constant dark energy equation of state model
  *
  * FIXME
+ * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -47,7 +48,7 @@ G_DEFINE_TYPE (NcHICosmoDEXcdm, nc_hicosmo_de_xcdm, NC_TYPE_HICOSMO_DE);
 static gdouble
 _nc_hicosmo_de_xcdm_weff (NcmModel *model, gdouble z)
 {
-  gdouble x = 1.0 + z;
+  const gdouble x = 1.0 + z;
   return OMEGA_X * pow (x, 3.0 * ( 1.0 + W ) );
 }
 
