@@ -28,7 +28,9 @@
  * @title: Baryonic Oscillation Data -- Acoustic Scale
  * @short_description: BAO acoustic scale estimator
  *
- * See <link linkend="XEisenstein2005">Eisenstein et al. (2005)</link>.
+ * The acoustic scale is defined as 
+ * $$ A \equiv D_V (z) \frac{\sqrt{\Omega_m H_0^2}}{z c}$$
+ * See Section 4.5 from <link linkend="XEisenstein2005">Eisenstein et al. (2005)</link>.
  * 
  */
 
@@ -159,7 +161,7 @@ static void
 _nc_data_bao_a_prepare (NcmData *data, NcmMSet *mset)
 {
   NcDataBaoA *bao_a = NC_DATA_BAO_A (data);
-  NcHICosmo *cosmo = NC_HICOSMO (ncm_mset_peek (mset, NC_HICOSMO_ID));
+  NcHICosmo *cosmo = NC_HICOSMO (ncm_mset_peek (mset, nc_hicosmo_id ()));
   nc_distance_prepare_if_needed (bao_a->dist, cosmo);
 }
 
@@ -167,7 +169,7 @@ static void
 _nc_data_bao_a_mean_func (NcmDataGaussDiag *diag, NcmMSet *mset, NcmVector *vp)
 {
   NcDataBaoA *bao_a = NC_DATA_BAO_A (diag);
-  NcHICosmo *cosmo = NC_HICOSMO (ncm_mset_peek (mset, NC_HICOSMO_ID));
+  NcHICosmo *cosmo = NC_HICOSMO (ncm_mset_peek (mset, nc_hicosmo_id ()));
   gint i;
   
   for (i = 0; i < diag->np; i++)
