@@ -54,8 +54,8 @@ nc_hicosmo_finalize (GObject *object)
   G_OBJECT_CLASS (nc_hicosmo_parent_class)->finalize (object);
 }
 
-gint32 NC_HICOSMO_ID = -1;
 static gboolean _nc_hicosmo_valid (NcmModel *model);
+NCM_MSET_MODEL_REGISTER_ID (nc_hicosmo, NC_TYPE_HICOSMO);
 
 static void
 nc_hicosmo_class_init (NcHICosmoClass *klass)
@@ -65,8 +65,10 @@ nc_hicosmo_class_init (NcHICosmoClass *klass)
   
   object_class->finalize = nc_hicosmo_finalize;
 
-  ncm_model_class_register_id (model_class);
-  NC_HICOSMO_ID = model_class->model_id;
+  ncm_mset_model_register_id (model_class, 
+                              "NcHICosmo",
+                              "Homogeneous and isotropic cosmological models.",
+                              NULL);
 
   model_class->valid = &_nc_hicosmo_valid;
 }
@@ -213,6 +215,24 @@ NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcmModelFunc0,sigma_8)
  *
  */
 NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcmModelFunc0,T_gamma0)
+/**
+ * nc_hicosmo_set_z_lss_impl: (skip)
+ * @model_class: FIXME
+ * @f: FIXME
+ *
+ * FIXME
+ *
+ */
+NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcmModelFunc0,z_lss)
+/**
+ * nc_hicosmo_set_as_drag_impl: (skip)
+ * @model_class: FIXME
+ * @f: FIXME
+ *
+ * FIXME
+ *
+ */
+NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcmModelFunc0,as_drag)
 
 /**
  * nc_hicosmo_set_E2_impl: (skip)
@@ -422,6 +442,30 @@ NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcmModelFunc1,powspec)
  *
  * Returns: FIXME
  */
+/**
+ * nc_hicosmo_Omega_bh2:
+ * @cosmo: a #NcHICosmo
+ *
+ * FIXME
+ *
+ * Returns: FIXME
+ */
+/**
+ * nc_hicosmo_Omega_ch2:
+ * @cosmo: a #NcHICosmo
+ *
+ * FIXME
+ *
+ * Returns: FIXME
+ */
+/**
+ * nc_hicosmo_Omega_rh2:
+ * @cosmo: a #NcHICosmo
+ *
+ * FIXME
+ *
+ * Returns: FIXME
+ */
 /**
  * nc_hicosmo_grad_h2:
  * @cosmo: a #NcHICosmo
@@ -435,9 +479,18 @@ NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcmModelFunc1,powspec)
  * @cosmo: a #NcHICosmo
  * @z: redshift
  *
- * FIXME
+ * This function computes the normalized Hubble function $E(z)$.
  *
- * Returns: FIXME
+ * Returns: $E(z)$.
+ */
+/**
+ * nc_hicosmo_Em2:
+ * @cosmo: a #NcHICosmo
+ * @z: redshift
+ *
+ * This function computes the inverse of the square normalized Hubble function.
+ *
+ * Returns: $E(z)^{-2}$.
  */
 /**
  * nc_hicosmo_grad_E:
@@ -465,7 +518,25 @@ NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcmModelFunc1,powspec)
  * FIXME
  *
  * Returns: FIXME
-*/
+ */
+/**
+ * nc_hicosmo_dec:
+ * @cosmo: a #NcHICosmo
+ * @z: redshift
+ *
+ * FIXME
+ *
+ * Returns: FIXME
+ */
+/**
+ * nc_hicosmo_wec:
+ * @cosmo: a #NcHICosmo
+ * @z: redshift
+ *
+ * FIXME
+ *
+ * Returns: FIXME
+ */
 /**
  * nc_hicosmo_qp:
  * @cosmo: a #NcHICosmo
@@ -489,14 +560,14 @@ static void
 _nc_hicosmo_func0 (NcmMSet *mset, gpointer obj, const gdouble *x, gdouble *f)
 {
   NcHICosmoFunc0 f0 = (NcHICosmoFunc0) obj;
-  f[0] = f0 (NC_HICOSMO (ncm_mset_peek (mset, NC_HICOSMO_ID)));
+  f[0] = f0 (NC_HICOSMO (ncm_mset_peek (mset, nc_hicosmo_id ())));
 }
 
 static void
 _nc_hicosmo_func1 (NcmMSet *mset, gpointer obj, const gdouble *x, gdouble *f)
 {
   NcHICosmoFunc1 f1 = (NcHICosmoFunc1) obj;
-  f[0] = f1 (NC_HICOSMO (ncm_mset_peek (mset, NC_HICOSMO_ID)), x[0]);
+  f[0] = f1 (NC_HICOSMO (ncm_mset_peek (mset, nc_hicosmo_id ())), x[0]);
 }
 
 /**
