@@ -39,7 +39,6 @@
 
 #include "sphere/map.h"
 #include "sphere/healpix.h"
-#include "nc_macros.h"
 #include "math/ncm_c.h"
 #include "math/ncm_cfg.h"
 #include "math/util.h"
@@ -54,18 +53,18 @@
 #endif /* NUMCOSMO_HAVE_CFITSIO */
 
 /**
- * nc_sphere_map_new: (skip)
+ * ncm_sphere_map_new: (skip)
  * @nside: FIXME
  *
  * FIXME
  *
  * Returns: FIXME
  */
-NcSphereMap *
-nc_sphere_map_new (gint nside)
+NcmSphereMap *
+ncm_sphere_map_new (gint nside)
 {
-  NcSphereMap *map = g_slice_new (NcSphereMap);
-  memset (map, 0, sizeof(NcSphereMap));
+  NcmSphereMap *map = g_slice_new (NcmSphereMap);
+  memset (map, 0, sizeof(NcmSphereMap));
   map->loaded = FALSE;
   map->is_init_coord = FALSE;
   map->type = 0;
@@ -80,22 +79,22 @@ nc_sphere_map_new (gint nside)
 }
 
 /**
- * nc_sphere_map_copy:
- * @dest: a #NcSphereMap
- * @orig: a #NcSphereMap
+ * ncm_sphere_map_copy:
+ * @dest: a #NcmSphereMap
+ * @orig: a #NcmSphereMap
  *
  * FIXME
  *
  * Returns: FIXME
  */
 gboolean
-nc_sphere_map_copy (NcSphereMap *dest, NcSphereMap *orig)
+ncm_sphere_map_copy (NcmSphereMap *dest, NcmSphereMap *orig)
 {
   gsl_vector_float **ovectors[] = {&orig->dt, &orig->qpol, &orig->upol, &orig->spur_signal, &orig->nobs};
   gsl_vector_float **dvectors[] = {&dest->dt, &dest->qpol, &dest->upol, &dest->spur_signal, &dest->nobs};
   gint i;
   g_assert (orig->nside == dest->nside);
-  nc_sphere_map_set_order (dest, orig->order, FALSE);
+  ncm_sphere_map_set_order (dest, orig->order, FALSE);
 
   for (i = 0; i < 5; i++)
   {
@@ -111,32 +110,32 @@ nc_sphere_map_copy (NcSphereMap *dest, NcSphereMap *orig)
 }
 
 /**
- * nc_sphere_map_clone: (skip)
- * @map: a #NcSphereMap
+ * ncm_sphere_map_clone: (skip)
+ * @map: a #NcmSphereMap
  *
  * FIXME
  *
  * Returns: FIXME
  */
-NcSphereMap *
-nc_sphere_map_clone (NcSphereMap *map)
+NcmSphereMap *
+ncm_sphere_map_clone (NcmSphereMap *map)
 {
-  NcSphereMap *clone = nc_sphere_map_new (map->nside);
-  nc_sphere_map_copy (clone, map);
+  NcmSphereMap *clone = ncm_sphere_map_new (map->nside);
+  ncm_sphere_map_copy (clone, map);
   clone->loaded = TRUE;
   return clone;
 }
 
 /**
- * nc_sphere_map_init_coord:
- * @map: a #NcSphereMap
+ * ncm_sphere_map_init_coord:
+ * @map: a #NcmSphereMap
  *
  * FIXME
  *
  * Returns: FIXME
  */
 gboolean
-nc_sphere_map_init_coord (NcSphereMap *map)
+ncm_sphere_map_init_coord (NcmSphereMap *map)
 {
   glong i;
   if (map->theta == NULL)
@@ -146,11 +145,11 @@ nc_sphere_map_init_coord (NcSphereMap *map)
 
   if (map->order == NC_SPHERE_MAP_ORDER_NEST)
     for (i = 0; i < map->npix; i++)
-      nc_sphere_healpix_pix2ang_nest (map->nside, i, gsl_vector_ptr (map->theta, i), gsl_vector_ptr (map->phi, i));
+      ncm_sphere_healpix_pix2ang_nest (map->nside, i, gsl_vector_ptr (map->theta, i), gsl_vector_ptr (map->phi, i));
   else
     for (i = 0; i < map->npix; i++)
   {
-      nc_sphere_healpix_pix2ang_ring (map->nside, i, gsl_vector_ptr (map->theta, i), gsl_vector_ptr (map->phi, i));
+      ncm_sphere_healpix_pix2ang_ring (map->nside, i, gsl_vector_ptr (map->theta, i), gsl_vector_ptr (map->phi, i));
 //    printf ("[%.6ld] %.16f\n", i, map->theta->data[i]);
   }
   map->is_init_coord = TRUE;
@@ -158,9 +157,9 @@ nc_sphere_map_init_coord (NcSphereMap *map)
 }
 
 /**
- * nc_sphere_map_set_order:
- * @map: a #NcSphereMap
- * @order: a #NcSphereMapOrder
+ * ncm_sphere_map_set_order:
+ * @map: a #NcmSphereMap
+ * @order: a #NcmSphereMapOrder
  * @init_coord: FIXME
  *
  * FIXME
@@ -168,13 +167,13 @@ nc_sphere_map_init_coord (NcSphereMap *map)
  * Returns: FIXME
  */
 gboolean
-nc_sphere_map_set_order (NcSphereMap *map, NcSphereMapOrder order, gboolean init_coord)
+ncm_sphere_map_set_order (NcmSphereMap *map, NcmSphereMapOrder order, gboolean init_coord)
 {
   gsl_vector_float **vectors[] = {&map->dt, &map->qpol, &map->upol, &map->spur_signal, &map->nobs};
   if (map->order != order)
   {
     gsl_vector_float *temp_pix = gsl_vector_float_alloc (map->npix);
-    glong (*convert)(gint,glong) = (order == NC_SPHERE_MAP_ORDER_NEST ? nc_sphere_healpix_ring2nest : nc_sphere_healpix_nest2ring);
+    glong (*convert)(gint,glong) = (order == NC_SPHERE_MAP_ORDER_NEST ? ncm_sphere_healpix_ring2nest : ncm_sphere_healpix_nest2ring);
     glong i, j;
     gint v;
 
@@ -197,7 +196,7 @@ nc_sphere_map_set_order (NcSphereMap *map, NcSphereMapOrder order, gboolean init
   }
 
   if (init_coord)
-    nc_sphere_map_init_coord (map);
+    ncm_sphere_map_init_coord (map);
   else
     map->is_init_coord = FALSE;
 
@@ -205,16 +204,16 @@ nc_sphere_map_set_order (NcSphereMap *map, NcSphereMapOrder order, gboolean init
 }
 
 /**
- * nc_sphere_mapalm_new: (skip)
+ * ncm_sphere_mapalm_new: (skip)
  *
  * FIXME
  *
  * Returns: FIXME
  */
-NcSphereMapAlm *
-nc_sphere_mapalm_new (void)
+NcmSphereMapAlm *
+ncm_sphere_mapalm_new (void)
 {
-  NcSphereMapAlm *mapalm = g_slice_new (NcSphereMapAlm);
+  NcmSphereMapAlm *mapalm = g_slice_new (NcmSphereMapAlm);
   mapalm->lmax = 0;
   mapalm->alm = NULL;
   mapalm->Nc = NULL;
@@ -223,8 +222,8 @@ nc_sphere_mapalm_new (void)
 }
 
 /**
- * nc_sphere_mapalm_init:
- * @mapalm: a #NcSphereMapAlm
+ * ncm_sphere_mapalm_init:
+ * @mapalm: a #NcmSphereMapAlm
  * @lmax: FIXME
  *
  * FIXME
@@ -232,13 +231,13 @@ nc_sphere_mapalm_new (void)
  * Returns: FIXME
  */
 gboolean
-nc_sphere_mapalm_init (NcSphereMapAlm *mapalm, gint lmax)
+ncm_sphere_mapalm_init (NcmSphereMapAlm *mapalm, gint lmax)
 {
   gint l, m;
   gdouble last_lnpoch = 0.5 * M_LNPI - M_LN2;
   gdouble sgn = -1.0;
   mapalm->lmax = lmax;
-  mapalm->alm_size = NC_MAP_ALM_SIZE(lmax);
+  mapalm->alm_size = NCM_MAP_ALM_SIZE(lmax);
   mapalm->alm = gsl_vector_complex_alloc (mapalm->alm_size);
   mapalm->Nc = gsl_vector_alloc (lmax + 1);
   mapalm->sqrt_int = gsl_vector_alloc (2*lmax + 3 + 1);
@@ -265,7 +264,7 @@ nc_sphere_mapalm_init (NcSphereMapAlm *mapalm, gint lmax)
 
   for (m = 0; m <= lmax; m++)
   {
-    gint start_index = NC_MAP_ALM_M_START(lmax, m);
+    gint start_index = NCM_MAP_ALM_M_START(lmax, m);
     for (l = m + 2; l <= lmax; l++)
     {
       gdouble rec1 =
@@ -291,23 +290,23 @@ nc_sphere_mapalm_init (NcSphereMapAlm *mapalm, gint lmax)
 
 #ifdef NUMCOSMO_HAVE_FFTW3
 /**
- * nc_sphere_mapsht_new: (skip)
- * @map: a #NcSphereMap
- * @mapalm: a #NcSphereMapAlm
+ * ncm_sphere_mapsht_new: (skip)
+ * @map: a #NcmSphereMap
+ * @mapalm: a #NcmSphereMapAlm
  * @fftw_flags: FIXME
  *
  * FIXME
  *
  * Returns: FIXME
  */
-NcSphereMapSHT *
-nc_sphere_mapsht_new (NcSphereMap *map, NcSphereMapAlm *mapalm, guint fftw_flags)
+NcmSphereMapSHT *
+ncm_sphere_mapsht_new (NcmSphereMap *map, NcmSphereMapAlm *mapalm, guint fftw_flags)
 {
-  NcSphereMapSHT *mapsht = g_slice_new (NcSphereMapSHT);
+  NcmSphereMapSHT *mapsht = g_slice_new (NcmSphereMapSHT);
   gint i, j = 0;
-  mapsht->n_rings = NC_MAP_N_RINGS(map->nside);
-  mapsht->max_ring_size = NC_MAP_MAX_RING_SIZE(map->nside);
-  mapsht->n_diff_rings = NC_MAP_N_DIFFERENT_SIZED_RINGS(map->nside);
+  mapsht->n_rings = NCM_MAP_N_RINGS(map->nside);
+  mapsht->max_ring_size = NCM_MAP_MAX_RING_SIZE(map->nside);
+  mapsht->n_diff_rings = NCM_MAP_N_DIFFERENT_SIZED_RINGS(map->nside);
   mapsht->map = map;
   mapsht->mapalm = mapalm;
   mapsht->ring = gsl_vector_alloc (mapsht->max_ring_size);
@@ -337,10 +336,10 @@ nc_sphere_mapsht_new (NcSphereMap *map, NcSphereMapAlm *mapalm, guint fftw_flags
 
   for (i = 0; i < mapsht->n_rings; i++)
   {
-    gint ring_size = NC_MAP_RING_SIZE(mapsht->map->nside, i);
+    gint ring_size = NCM_MAP_RING_SIZE(mapsht->map->nside, i);
     gsl_vector_complex_view fft_ring_view = gsl_matrix_complex_row (mapsht->fft_ring, i);
     gdouble theta, phi;
-    nc_sphere_healpix_pix2ang_ring (mapsht->map->nside, j, &theta, &phi);
+    ncm_sphere_healpix_pix2ang_ring (mapsht->map->nside, j, &theta, &phi);
 
     j += ring_size;
     mapsht->forward_plans[i] =
@@ -362,8 +361,8 @@ nc_sphere_mapsht_new (NcSphereMap *map, NcSphereMapAlm *mapalm, guint fftw_flags
 }
 
 /**
- * nc_sphere_mapsht_map2alm:
- * @mapsht: a #NcSphereMapSHT
+ * ncm_sphere_mapsht_map2alm:
+ * @mapsht: a #NcmSphereMapSHT
  * @cut: FIXME
  *
  * Transform the map to alm circle by circle using fft in each one
@@ -371,7 +370,7 @@ nc_sphere_mapsht_new (NcSphereMap *map, NcSphereMapAlm *mapalm, guint fftw_flags
  * Returns: FIXME
  */
 gboolean
-nc_sphere_mapsht_map2alm (NcSphereMapSHT *mapsht, gdouble cut)
+ncm_sphere_mapsht_map2alm (NcmSphereMapSHT *mapsht, gdouble cut)
 {
   gint i, j = 0;
   gint start_m = 0;
@@ -387,7 +386,7 @@ nc_sphere_mapsht_map2alm (NcSphereMapSHT *mapsht, gdouble cut)
 
   for (i = 0; i < mapsht->n_rings; i++)
   {
-    gint ring_size = NC_MAP_RING_SIZE (mapsht->map->nside, i);
+    gint ring_size = NCM_MAP_RING_SIZE (mapsht->map->nside, i);
     last_ring_pix += ring_size;
     for (; j < last_ring_pix; j++)
       gsl_vector_set (mapsht->ring, j - last_ring_pix + ring_size,
@@ -407,12 +406,12 @@ nc_sphere_mapsht_map2alm (NcSphereMapSHT *mapsht, gdouble cut)
 
     for (i = 0; i < mapsht->n_rings; i++)
     {
-      gint ring_size = NC_MAP_RING_SIZE (mapsht->map->nside, i);
+      gint ring_size = NCM_MAP_RING_SIZE (mapsht->map->nside, i);
       gdouble theta, phi;
-      nc_sphere_healpix_pix2ang_ring (mapsht->map->nside, j, &theta, &phi);
+      ncm_sphere_healpix_pix2ang_ring (mapsht->map->nside, j, &theta, &phi);
       j += ring_size;
       if (fabs(theta - M_PI / 2.0) >= ncm_c_degree_to_radian (cut))
-        nc_sphere_mapsht_map2alm_circle (mapsht, i, ring_size, four_pi_npix, theta, phi, start_m, end_m);
+        ncm_sphere_mapsht_map2alm_circle (mapsht, i, ring_size, four_pi_npix, theta, phi, start_m, end_m);
     }
     start_m = end_m + 1;
   }
@@ -420,13 +419,13 @@ nc_sphere_mapsht_map2alm (NcSphereMapSHT *mapsht, gdouble cut)
   for (i = 0; i <= mapsht->mapalm->lmax; i++)
   {
     gdouble *Nc = gsl_vector_ptr (mapsht->mapalm->Nc, i);
-    *Nc = (gsl_pow_2 (GSL_REAL(gsl_vector_complex_get (mapsht->mapalm->alm, NC_MAP_ALM_INDEX(mapsht->mapalm->lmax, i, 0))))
-        + gsl_pow_2 (GSL_IMAG(gsl_vector_complex_get (mapsht->mapalm->alm, NC_MAP_ALM_INDEX(mapsht->mapalm->lmax, i, 0)))));
+    *Nc = (gsl_pow_2 (GSL_REAL(gsl_vector_complex_get (mapsht->mapalm->alm, NCM_MAP_ALM_INDEX(mapsht->mapalm->lmax, i, 0))))
+        + gsl_pow_2 (GSL_IMAG(gsl_vector_complex_get (mapsht->mapalm->alm, NCM_MAP_ALM_INDEX(mapsht->mapalm->lmax, i, 0)))));
     for (j = 1; j <= i; j++)
     {
       *Nc += 2.0 *
-        (gsl_pow_2 (GSL_REAL(gsl_vector_complex_get (mapsht->mapalm->alm, NC_MAP_ALM_INDEX(mapsht->mapalm->lmax, i, j))))
-        + gsl_pow_2 (GSL_IMAG(gsl_vector_complex_get (mapsht->mapalm->alm, NC_MAP_ALM_INDEX(mapsht->mapalm->lmax, i, j)))));
+        (gsl_pow_2 (GSL_REAL(gsl_vector_complex_get (mapsht->mapalm->alm, NCM_MAP_ALM_INDEX(mapsht->mapalm->lmax, i, j))))
+        + gsl_pow_2 (GSL_IMAG(gsl_vector_complex_get (mapsht->mapalm->alm, NCM_MAP_ALM_INDEX(mapsht->mapalm->lmax, i, j)))));
     }
     *Nc /= (2.0 * i + 1.0);
   }
@@ -435,8 +434,8 @@ nc_sphere_mapsht_map2alm (NcSphereMapSHT *mapsht, gdouble cut)
 }
 
 /**
- * nc_sphere_mapsht_map2alm_circle:
- * @mapsht: a #NcSphereMapSHT
+ * ncm_sphere_mapsht_map2alm_circle:
+ * @mapsht: a #NcmSphereMapSHT
  * @ring: FIXME
  * @ring_size: FIXME
  * @norma: FIXME
@@ -452,7 +451,7 @@ nc_sphere_mapsht_map2alm (NcSphereMapSHT *mapsht, gdouble cut)
  * Returns: FIXME
  */
 gboolean
-nc_sphere_mapsht_map2alm_circle (NcSphereMapSHT *mapsht, gint ring, gint ring_size, gdouble norma, gdouble theta, gdouble phi, gint start_m, gint end_m)
+ncm_sphere_mapsht_map2alm_circle (NcmSphereMapSHT *mapsht, gint ring, gint ring_size, gdouble norma, gdouble theta, gdouble phi, gint start_m, gint end_m)
 {
   gint lmax = mapsht->mapalm->lmax;
   gint m;
@@ -463,7 +462,7 @@ nc_sphere_mapsht_map2alm_circle (NcSphereMapSHT *mapsht, gint ring, gint ring_si
   gsl_vector_complex *alm = mapsht->mapalm->alm;
   gsl_complex exp_mphi;
   gsl_complex gphase;
-  gsl_complex *alm_data = (gsl_complex *)&alm->data[2*NC_MAP_ALM_M_START(lmax, start_m)];
+  gsl_complex *alm_data = (gsl_complex *)&alm->data[2*NCM_MAP_ALM_M_START(lmax, start_m)];
   gsl_vector_complex_view fft_ring_view = gsl_matrix_complex_row (mapsht->fft_ring, ring);
   gsl_vector_complex *fft_ring = &fft_ring_view.vector;
   GSL_SET_COMPLEX (&exp_mphi, cos(phi), -sin(phi));
@@ -471,19 +470,19 @@ nc_sphere_mapsht_map2alm_circle (NcSphereMapSHT *mapsht, gint ring, gint ring_si
 
   for (m = start_m; m <= lmax && m <= end_m; m++)
   {
-    gint start_index = NC_MAP_ALM_M_START(lmax, m);
+    gint start_index = NCM_MAP_ALM_M_START(lmax, m);
     gint fft_ring_index = m % ring_size;
     gsl_complex phase = gphase;
     if (gsl_vector_get (mapsht->sphPlm_upper_limit, m) < fabs(x))
       return TRUE;
-    NC_COMPLEX_MUL(gphase, exp_mphi);
+    NCM_COMPLEX_MUL(gphase, exp_mphi);
 
     if (fft_ring_index <= ring_size/2)
-      NC_COMPLEX_MUL (phase, gsl_vector_complex_get (fft_ring, fft_ring_index));
+      NCM_COMPLEX_MUL (phase, gsl_vector_complex_get (fft_ring, fft_ring_index));
     else
     {
       fft_ring_index = ring_size-fft_ring_index;
-      NC_COMPLEX_MUL_CONJUGATE (phase, gsl_vector_complex_get (fft_ring, fft_ring_index));
+      NCM_COMPLEX_MUL_CONJUGATE (phase, gsl_vector_complex_get (fft_ring, fft_ring_index));
     }
 
     if(m == 0)
@@ -500,21 +499,21 @@ nc_sphere_mapsht_map2alm_circle (NcSphereMapSHT *mapsht, gint ring, gint ring_si
 
     if(lmax == m)
     {
-      NC_COMPLEX_INC_MUL_REAL(alm_data[0], phase, y_mm);
+      NCM_COMPLEX_INC_MUL_REAL(alm_data[0], phase, y_mm);
       alm_data = &alm_data[1];
     }
     else if(lmax == m + 1)
     {
-      NC_COMPLEX_INC_MUL_REAL(alm_data[0], phase, y_mm);
-      NC_COMPLEX_INC_MUL_REAL(alm_data[1], phase, y_mmp1);
+      NCM_COMPLEX_INC_MUL_REAL(alm_data[0], phase, y_mm);
+      NCM_COMPLEX_INC_MUL_REAL(alm_data[1], phase, y_mmp1);
       alm_data = &alm_data[2];
     }
     else
     {
       gdouble y_ell = 0.0;
       gint ell, rindex, lindex;
-      NC_COMPLEX_INC_MUL_REAL(alm_data[0], phase, y_mm);
-      NC_COMPLEX_INC_MUL_REAL(alm_data[1], phase, y_mmp1);
+      NCM_COMPLEX_INC_MUL_REAL(alm_data[0], phase, y_mm);
+      NCM_COMPLEX_INC_MUL_REAL(alm_data[1], phase, y_mmp1);
 
       /* Compute Y_l^m, l > m+1, upward recursion on l. */
       rindex = start_index + 2;
@@ -526,7 +525,7 @@ nc_sphere_mapsht_map2alm_circle (NcSphereMapSHT *mapsht, gint ring, gint ring_si
         y_ell  = (x*y_mmp1*factor1 - y_mm*factor2);
         y_mm   = y_mmp1;
         y_mmp1 = y_ell;
-        NC_COMPLEX_INC_MUL_REAL(alm_data[lindex], phase, y_ell);
+        NCM_COMPLEX_INC_MUL_REAL(alm_data[lindex], phase, y_ell);
         rindex++;
         lindex++;
       }
@@ -537,15 +536,15 @@ nc_sphere_mapsht_map2alm_circle (NcSphereMapSHT *mapsht, gint ring, gint ring_si
 }
 
 /**
- * nc_sphere_mapsht_alm2map:
- * @mapsht: a #NcSphereMapSHT
+ * ncm_sphere_mapsht_alm2map:
+ * @mapsht: a #NcmSphereMapSHT
  *
  * FIXME
  *
  * Returns: FIXME
  */
 gboolean
-nc_sphere_mapsht_alm2map (NcSphereMapSHT *mapsht)
+ncm_sphere_mapsht_alm2map (NcmSphereMapSHT *mapsht)
 {
   gint i, j = 0;
   glong last_ring_pix = 0;
@@ -556,16 +555,16 @@ nc_sphere_mapsht_alm2map (NcSphereMapSHT *mapsht)
 
   for (i = 0; i < mapsht->n_rings; i++)
   {
-    gint plan_index = NC_MAP_RING_PLAN_INDEX (mapsht->map->nside, i);
+    gint plan_index = NCM_MAP_RING_PLAN_INDEX (mapsht->map->nside, i);
     gint ring_size = 4*(plan_index+1);
     gdouble theta, phi;
     gsl_vector_complex_view fft_ring_view = gsl_matrix_complex_row (mapsht->fft_ring, i);
     gsl_vector_complex *fft_ring = &fft_ring_view.vector;
 
-    nc_sphere_healpix_pix2ang_ring (mapsht->map->nside, j, &theta, &phi);
+    ncm_sphere_healpix_pix2ang_ring (mapsht->map->nside, j, &theta, &phi);
     last_ring_pix += ring_size;
 
-    nc_sphere_mapsht_alm2map_circle (mapsht, i, ring_size, theta, phi);
+    ncm_sphere_mapsht_alm2map_circle (mapsht, i, ring_size, theta, phi);
 
     fftw_execute (mapsht->backward_plans[i]);
 
@@ -589,8 +588,8 @@ nc_sphere_mapsht_alm2map (NcSphereMapSHT *mapsht)
 }
 
 /**
- * nc_sphere_mapsht_alm2map_circle:
- * @mapsht: a #NcSphereMapSHT
+ * ncm_sphere_mapsht_alm2map_circle:
+ * @mapsht: a #NcmSphereMapSHT
  * @ring: FIXME
  * @ring_size: FIXME
  * @theta: FIXME
@@ -604,7 +603,7 @@ nc_sphere_mapsht_alm2map (NcSphereMapSHT *mapsht)
  * Returns: FIXME
  */
 gboolean
-nc_sphere_mapsht_alm2map_circle (NcSphereMapSHT *mapsht, gint ring,  gint ring_size, gdouble theta, gdouble phi)
+ncm_sphere_mapsht_alm2map_circle (NcmSphereMapSHT *mapsht, gint ring,  gint ring_size, gdouble theta, gdouble phi)
 {
   gint lmax = mapsht->mapalm->lmax;
   gint m;
@@ -626,12 +625,12 @@ nc_sphere_mapsht_alm2map_circle (NcSphereMapSHT *mapsht, gint ring,  gint ring_s
 
   for (m = 0; m <= lmax; m++)
   {
-    gint start_index = NC_MAP_ALM_M_START(lmax, m);
+    gint start_index = NCM_MAP_ALM_M_START(lmax, m);
     gsl_complex phase = gphase;
     gsl_complex temp_sum;
     gsl_complex *fft_ring_i = gsl_vector_complex_ptr (fft_ring, m % ring_size);
     GSL_SET_COMPLEX (&temp_sum, 0.0, 0.0);
-    NC_COMPLEX_MUL(gphase, exp_mphi);
+    NCM_COMPLEX_MUL(gphase, exp_mphi);
 
     if(m == 0)
     {
@@ -649,13 +648,13 @@ nc_sphere_mapsht_alm2map_circle (NcSphereMapSHT *mapsht, gint ring,  gint ring_s
 
     if(lmax == m)
     {
-      NC_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[0], y_mm);
+      NCM_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[0], y_mm);
       alm_data = &alm_data[1];
     }
     else if(lmax == m + 1)
     {
-      NC_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[0], y_mm);
-      NC_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[1], y_mmp1);
+      NCM_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[0], y_mm);
+      NCM_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[1], y_mmp1);
       alm_data = &alm_data[2];
     }
     else
@@ -663,8 +662,8 @@ nc_sphere_mapsht_alm2map_circle (NcSphereMapSHT *mapsht, gint ring,  gint ring_s
       gdouble y_ell = 0.0;
       gint ell, rindex, lindex;
 
-      NC_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[0], y_mm);
-      NC_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[1], y_mmp1);
+      NCM_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[0], y_mm);
+      NCM_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[1], y_mmp1);
 
       /* Compute Y_l^m, l > m+1, upward recursion on l. */
       rindex = start_index + 2;
@@ -676,14 +675,14 @@ nc_sphere_mapsht_alm2map_circle (NcSphereMapSHT *mapsht, gint ring,  gint ring_s
         y_ell  = (x*y_mmp1*factor1 - y_mm*factor2);
         y_mm   = y_mmp1;
         y_mmp1 = y_ell;
-        NC_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[lindex], y_ell);
+        NCM_COMPLEX_INC_MUL_REAL (temp_sum, alm_data[lindex], y_ell);
         rindex++;
         lindex++;
       }
       alm_data = &alm_data[lindex];
     }
-    NC_COMPLEX_MUL(temp_sum, phase);
-    NC_COMPLEX_ADD(*fft_ring_i, temp_sum);
+    NCM_COMPLEX_MUL(temp_sum, phase);
+    NCM_COMPLEX_ADD(*fft_ring_i, temp_sum);
     //printf ("[%d %d] ==> %g %g\n", m, m % ring_size, GSL_REAL(temp_sum), GSL_IMAG(temp_sum));
   }
   return TRUE;
@@ -691,8 +690,8 @@ nc_sphere_mapsht_alm2map_circle (NcSphereMapSHT *mapsht, gint ring,  gint ring_s
 #endif /* NUMCOSMO_HAVE_FFTW3 */
 
 /**
- * nc_sphere_map_homogenize_noise:
- * @map: a #NcSphereMap
+ * ncm_sphere_map_homogenize_noise:
+ * @map: a #NcmSphereMap
  * @base_sigma: FIXME
  *
  * FIXME
@@ -700,7 +699,7 @@ nc_sphere_mapsht_alm2map_circle (NcSphereMapSHT *mapsht, gint ring,  gint ring_s
  * Returns: FIXME
  */
 gdouble
-nc_sphere_map_homogenize_noise (NcSphereMap *map, gdouble base_sigma)
+ncm_sphere_map_homogenize_noise (NcmSphereMap *map, gdouble base_sigma)
 {
   gfloat min;
   gdouble sigma_m;
@@ -724,8 +723,8 @@ nc_sphere_map_homogenize_noise (NcSphereMap *map, gdouble base_sigma)
 }
 
 /**
- * nc_sphere_map_rotate_avg:
- * @map: a #NcSphereMap
+ * ncm_sphere_map_rotate_avg:
+ * @map: a #NcmSphereMap
  * @n: FIXME
  *
  * FIXME
@@ -733,23 +732,23 @@ nc_sphere_map_homogenize_noise (NcSphereMap *map, gdouble base_sigma)
  * Returns: FIXME
  */
 gdouble
-nc_sphere_map_rotate_avg (NcSphereMap *map, glong n)
+ncm_sphere_map_rotate_avg (NcmSphereMap *map, glong n)
 {
-  NcQ *q = nc_quaternion_new ();
-  NcTriVector v = NC_TRIVEC_NEW;
-  NcSphereMap *ramap = nc_sphere_map_clone (map);
+  NcmQ *q = ncm_quaternion_new ();
+  NcmTriVector v = NC_TRIVEC_NEW;
+  NcmSphereMap *ramap = ncm_sphere_map_clone (map);
   glong i, j = n;
   g_assert (n > 0);
 
   while (j--)
   {
-    nc_quaternion_set_random (q);
+    ncm_quaternion_set_random (q);
     for (i = 0; i < map->npix; i++)
     {
       glong ri = i;
-      nc_sphere_healpix_pix2vec_ring (map->nside, i, v);
-      nc_quaternion_rotate (q, v);
-      nc_sphere_healpix_vec2pix_ring (map->nside, v, &ri);
+      ncm_sphere_healpix_pix2vec_ring (map->nside, i, v);
+      ncm_quaternion_rotate (q, v);
+      ncm_sphere_healpix_vec2pix_ring (map->nside, v, &ri);
       gsl_vector_float_set (ramap->dt, i,
                             gsl_vector_float_get (ramap->dt, i) +
                             gsl_vector_float_get (map->dt, ri));
@@ -760,7 +759,7 @@ nc_sphere_map_rotate_avg (NcSphereMap *map, glong n)
   for (i = 0; i < map->npix; i++)
     gsl_vector_float_set (map->dt, i, gsl_vector_float_get (ramap->dt, i) / (1.0 * n + 1.0));
 
-  //nc_sphere_map_free (ramap);
+  //ncm_sphere_map_free (ramap);
 
   return TRUE;
 }
