@@ -224,13 +224,13 @@ test_ncm_spline2d_bicubic_notaknot_new_empty (void)
 }
 
 /*
- void
- test_ncm_spline2d_bicubic_spline_new_empty (void)
- {
-   s2d_base = ncm_spline2d_bicubic_new (s_base);
-   g_assert (NCM_IS_SPLINE2D_BICUBIC (s2d_base));
-   }
-   */
+ * void
+ * test_ncm_spline2d_bicubic_spline_new_empty (void)
+ * {
+ *   s2d_base = ncm_spline2d_bicubic_new (s_base);
+ *   g_assert (NCM_IS_SPLINE2D_BICUBIC (s2d_base));
+ * }
+ */
 void
 test_ncm_spline2d_gsl_cspline_new_empty (void)
 {
@@ -239,14 +239,13 @@ test_ncm_spline2d_gsl_cspline_new_empty (void)
   g_assert (NCM_IS_SPLINE2D_GSL (s2d_base));
 }
 /*
- void
- test_ncm_spline2d_gsl_spline_new_empty (void)
- {
-   s2d_base = ncm_spline2d_gsl_new (s_base);
-   g_assert (NCM_IS_SPLINE2D_GSL (s2d_base));
-   }
-   */
-
+ * void
+ * test_ncm_spline2d_gsl_spline_new_empty (void)
+ * {
+ *   s2d_base = ncm_spline2d_gsl_new (s_base);
+ *   g_assert (NCM_IS_SPLINE2D_GSL (s2d_base));
+ * }
+ */
 void
 test_ncm_spline2d_spline_new_empty (void)
 {
@@ -431,10 +430,11 @@ test_ncm_spline2d_copy (void)
     g_assert (s2d_cp->xv != s2d->xv && s2d_cp->yv != s2d->yv && s2d_cp->zm != s2d->zm);
     for (j = 0; j < _NCM_SPLINE2D_TEST_NKNOTS_Y; j++)
     {
-      g_assert (ncm_vector_get (s2d_cp->yv, j) == ncm_vector_get (s2d->yv, j));
+      ncm_assert_cmpdouble (ncm_vector_get (s2d_cp->yv, j), ==, ncm_vector_get (s2d->yv, j));
       for (i = 0; i < _NCM_SPLINE2D_TEST_NKNOTS_X; i++)
       {
-        g_assert (ncm_vector_get (s2d_cp->xv, i) == ncm_vector_get (s2d->xv, i) && ncm_matrix_get (s2d_cp->zm, j, i) == ncm_matrix_get (s2d->zm, j, i));
+        ncm_assert_cmpdouble (ncm_vector_get (s2d_cp->xv, i), ==, ncm_vector_get (s2d->xv, i));
+        ncm_assert_cmpdouble (ncm_matrix_get (s2d_cp->zm, j, i), ==, ncm_matrix_get (s2d->zm, j, i));
       }
     }
 
@@ -484,9 +484,8 @@ test_ncm_spline2d_eval (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * _NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) * i;
         gdouble f = F_linear (x, y, d);
         gdouble fs = ncm_spline2d_eval (s2d, x, y);
-        gdouble err = (f != 0.0 ? fabs ((fs - f) / f) : fabs (fs));
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g %.5e\n", x, y, f, fs, err);
-        g_assert (test_error > err);
+
+        ncm_assert_cmpdouble_e (fs, ==, f, test_error);
       }
     }
     ncm_spline2d_free (s2d);
@@ -521,9 +520,8 @@ test_ncm_spline2d_eval (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * _NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) * i;
         gdouble f = F_poly (x, y, d);
         gdouble fs = ncm_spline2d_eval (s2d, x, y);
-        gdouble err = (f != 0.0 ? fabs ((fs - f) / f) : fabs (fs));
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g %.5e\n", x, y, f, fs, err);
-        g_assert (test_error > err);
+
+        ncm_assert_cmpdouble_e (fs, ==, f, test_error);
       }
     }
     ncm_spline2d_free (s2d);
@@ -568,10 +566,8 @@ test_ncm_spline2d_eval (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * npx - 1.0) * i;
         gdouble f = F_func (x, y, d);
         gdouble fs = ncm_spline2d_eval (s2d, x, y);
-        gdouble err = (f != 0.0 ? fabs ((fs - f) / f) : fabs (fs));
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g %.5e\n", x, y, f, fs, err);
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g\n", x, y, f);
-        g_assert (test_error > err);
+
+        ncm_assert_cmpdouble_e (fs, ==, f, test_error);
       }
     }
     ncm_spline2d_free (s2d);
@@ -619,9 +615,8 @@ test_ncm_spline2d_eval_integ_dx (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * _NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) * i;
         gdouble f = F_linear_intx (x, y, d) - F_linear_intx (_NCM_SPLINE2D_TEST_XI, y, d);
         gdouble fs = ncm_spline2d_integ_dx (s2d, _NCM_SPLINE2D_TEST_XI, x, y);
-        gdouble err = (f != 0.0 ? fabs ((fs - f) / f) : fabs (fs));
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g %.5e\n", x, y, f, fs, err);
-        g_assert (test_error > err);
+
+        ncm_assert_cmpdouble_e (fs, ==, f, test_error);
       }
     }
     ncm_spline2d_free (s2d);
@@ -656,9 +651,8 @@ test_ncm_spline2d_eval_integ_dx (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * _NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) * i;
         gdouble f = F_poly_intx (x, y, d) - F_poly_intx (_NCM_SPLINE2D_TEST_XI, y, d);
         gdouble fs = ncm_spline2d_integ_dx (s2d, _NCM_SPLINE2D_TEST_XI, x, y);
-        gdouble err = (f != 0.0 ? fabs ((fs - f) / f) : fabs (fs));
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g %.5e\n", x, y, f, fs, err);
-        g_assert (test_error > err);
+
+        ncm_assert_cmpdouble_e (fs, ==, f, test_error);
       }
     }
     ncm_spline2d_free (s2d);
@@ -705,9 +699,8 @@ test_ncm_spline2d_eval_integ_dy (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * _NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) * i;
         gdouble f = F_linear_inty (x, y, d) - F_linear_inty (x, _NCM_SPLINE2D_TEST_YI, d);
         gdouble fs = ncm_spline2d_integ_dy (s2d, x, _NCM_SPLINE2D_TEST_YI, y);
-        gdouble err = (f != 0.0 ? fabs ((fs - f) / f) : fabs (fs));
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g %.5e\n", x, y, f, fs, err);
-        g_assert (test_error > err);
+
+        ncm_assert_cmpdouble_e (fs, ==, f, test_error);
       }
     }
     ncm_spline2d_free (s2d);
@@ -742,9 +735,8 @@ test_ncm_spline2d_eval_integ_dy (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * _NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) * i;
         gdouble f = F_poly_inty (x, y, d) - F_poly_inty (x, _NCM_SPLINE2D_TEST_YI, d);
         gdouble fs = ncm_spline2d_integ_dy (s2d, x, _NCM_SPLINE2D_TEST_YI, y);
-        gdouble err = (f != 0.0 ? fabs ((fs - f) / f) : fabs (fs));
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g %.5e\n", x, y, f, fs, err);
-        g_assert (test_error > err);
+
+        ncm_assert_cmpdouble_e (fs, ==, f, test_error);
       }
     }
     ncm_spline2d_free (s2d);
@@ -791,9 +783,8 @@ test_ncm_spline2d_eval_integ_dxdy (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * _NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) * i;
         gdouble f = F_linear_intxy (x, y, d) - F_linear_intxy (_NCM_SPLINE2D_TEST_XI, y, d) - F_linear_intxy (x, _NCM_SPLINE2D_TEST_YI, d) + F_linear_intxy (_NCM_SPLINE2D_TEST_XI, _NCM_SPLINE2D_TEST_YI, d);
         gdouble fs = ncm_spline2d_integ_dxdy (s2d, _NCM_SPLINE2D_TEST_XI, x, _NCM_SPLINE2D_TEST_YI, y);
-        gdouble err = (f != 0.0 ? fabs ((fs - f) / f) : fabs (fs));
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g %.5e\n", x, y, f, fs, err);
-        g_assert (test_error > err);
+
+        ncm_assert_cmpdouble_e (fs, ==, f, test_error);
       }
     }
     ncm_spline2d_free (s2d);
@@ -828,9 +819,8 @@ test_ncm_spline2d_eval_integ_dxdy (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * _NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) * i;
         gdouble f = F_poly_intxy (x, y, d) - F_poly_intxy (_NCM_SPLINE2D_TEST_XI, y, d) - F_poly_intxy (x, _NCM_SPLINE2D_TEST_YI, d) + F_poly_intxy (_NCM_SPLINE2D_TEST_XI, _NCM_SPLINE2D_TEST_YI, d);
         gdouble fs = ncm_spline2d_integ_dxdy (s2d, _NCM_SPLINE2D_TEST_XI, x, _NCM_SPLINE2D_TEST_YI, y);
-        gdouble err = (f != 0.0 ? fabs ((fs - f) / f) : fabs (fs));
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g %.5e\n", x, y, f, fs, err);
-        g_assert (test_error > err);
+
+        ncm_assert_cmpdouble_e (fs, ==, f, test_error);
       }
     }
     ncm_spline2d_free (s2d);
@@ -877,24 +867,18 @@ test_ncm_spline2d_eval_integ_x_y_xy_spline (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * _NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) * i;
         gdouble f_int_x = ncm_spline2d_integ_dx (s2d, _NCM_SPLINE2D_TEST_XI, x, y);
         gdouble f_int_sx = ncm_spline2d_integ_dx_spline_val (s2d, _NCM_SPLINE2D_TEST_XI, x, y);
-        gdouble epsilon1 = (f_int_x != 0.0 ? fabs ((f_int_sx - f_int_x) / f_int_x) : fabs (f_int_sx));
 
         gdouble f_int_y = ncm_spline2d_integ_dy (s2d, x, _NCM_SPLINE2D_TEST_YI, y);
         gdouble f_int_sy = ncm_spline2d_integ_dy_spline_val (s2d, x, _NCM_SPLINE2D_TEST_YI, y);
-        gdouble epsilon2 = (f_int_y != 0.0 ? fabs ((f_int_sy - f_int_y) / f_int_y) : fabs (f_int_sy));
 
         gdouble f_int_xy = ncm_spline2d_integ_dxdy (s2d, _NCM_SPLINE2D_TEST_XI, x, _NCM_SPLINE2D_TEST_YI, y);
         gdouble fs_x = ncm_spline2d_integ_dxdy_spline_x (s2d, _NCM_SPLINE2D_TEST_XI, x, _NCM_SPLINE2D_TEST_YI, y);
-        gdouble epsilon3 = (f_int_xy != 0.0 ? fabs ((fs_x - f_int_xy) / f_int_xy) : fabs (fs_x));
-
         gdouble fs_y = ncm_spline2d_integ_dxdy_spline_y (s2d, _NCM_SPLINE2D_TEST_XI, x, _NCM_SPLINE2D_TEST_YI, y);
-        gdouble epsilon4 = (f_int_xy != 0.0 ? fabs ((fs_y - f_int_xy) / f_int_xy) : fabs (fs_y));
 
-        g_assert (epsilon1 <= test_error);
-        g_assert (epsilon2 <= test_error);
-        g_assert (epsilon3 <= test_error);
-        g_assert (epsilon4 <= test_error);
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g\n", x, y, f_int_y, f_int_sy);
+        ncm_assert_cmpdouble_e (f_int_x, ==, f_int_sx, test_error);
+        ncm_assert_cmpdouble_e (f_int_y, ==, f_int_sy, test_error);
+        ncm_assert_cmpdouble_e (f_int_xy, ==, fs_x, test_error);
+        ncm_assert_cmpdouble_e (f_int_xy, ==, fs_y, test_error);
       }
     }
     ncm_spline2d_free (s2d);
@@ -950,24 +934,19 @@ test_ncm_spline2d_eval_integ_x_y_xy_spline (void)
         gdouble x = _NCM_SPLINE2D_TEST_XI + _NCM_SPLINE2D_TEST_DX * (_NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) / (2.0 * _NCM_SPLINE2D_TEST_NKNOTS_X - 1.0) * i;
         gdouble f_int_x = ncm_spline2d_integ_dx (s2d, _NCM_SPLINE2D_TEST_XI, x, y);
         gdouble f_int_sx = ncm_spline2d_integ_dx_spline_val (s2d, _NCM_SPLINE2D_TEST_XI, x, y);
-        gdouble epsilon1 = (f_int_x != 0.0 ? fabs ((f_int_sx - f_int_x) / f_int_x) : fabs (f_int_sx));
 
         gdouble f_int_y = ncm_spline2d_integ_dy (s2d, x, _NCM_SPLINE2D_TEST_YI, y);
         gdouble f_int_sy = ncm_spline2d_integ_dy_spline_val (s2d, x, _NCM_SPLINE2D_TEST_YI, y);
-        gdouble epsilon2 = (f_int_y != 0.0 ? fabs ((f_int_sy - f_int_y) / f_int_y) : fabs (f_int_sy));
 
         gdouble f_int_xy = ncm_spline2d_integ_dxdy (s2d, _NCM_SPLINE2D_TEST_XI, x, _NCM_SPLINE2D_TEST_YI, y);
         gdouble fs_x = ncm_spline2d_integ_dxdy_spline_x (s2d, _NCM_SPLINE2D_TEST_XI, x, _NCM_SPLINE2D_TEST_YI, y);
-        gdouble epsilon3 = (f_int_xy != 0.0 ? fabs ((fs_x - f_int_xy) / f_int_xy) : fabs (fs_x));
 
         gdouble fs_y = ncm_spline2d_integ_dxdy_spline_y (s2d, _NCM_SPLINE2D_TEST_XI, x, _NCM_SPLINE2D_TEST_YI, y);
-        gdouble epsilon4 = (f_int_xy != 0.0 ? fabs ((fs_y - f_int_xy) / f_int_xy) : fabs (fs_y));
 
-        g_assert (epsilon1 <= test_error);
-        g_assert (epsilon2 <= test_error);
-        g_assert (epsilon3 <= test_error);
-        g_assert (epsilon4 <= test_error);
-        //printf ("x = % 20.15g y = % 20.15g z = % 20.15g % 20.15g\n", x, y, f_int_y, f_int_sy);
+        ncm_assert_cmpdouble_e (f_int_sx, ==, f_int_x, test_error);
+        ncm_assert_cmpdouble_e (f_int_sy, ==, f_int_y, test_error);
+        ncm_assert_cmpdouble_e (f_int_xy, ==, fs_x, test_error);
+        ncm_assert_cmpdouble_e (f_int_xy, ==, fs_y, test_error);
       }
     }
     ncm_spline2d_free (s2d);
